package android.car;

import android.bluetooth.BluetoothDevice;
import android.car.CarProjectionManager;
import android.car.ICarProjection;
import android.car.ICarProjectionKeyEventHandler;
import android.car.ICarProjectionStatusListener;
import android.car.projection.ProjectionStatus;
import android.content.Intent;
import android.net.wifi.SoftApConfiguration;
import android.net.wifi.WifiConfiguration;
import android.os.Binder;
import android.os.Bundle;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper;
import android.os.Message;
import android.os.Messenger;
import android.os.RemoteException;
import android.util.ArraySet;
import android.util.Log;
import android.util.Pair;
import com.android.internal.util.Preconditions;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.BitSet;
import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Set;
import java.util.concurrent.Executor;

public final class CarProjectionManager extends CarManagerBase {
    public static final int KEY_EVENT_CALL_KEY_DOWN;
    public static final int KEY_EVENT_CALL_LONG_PRESS_KEY_DOWN;
    public static final int KEY_EVENT_CALL_LONG_PRESS_KEY_UP;
    public static final int KEY_EVENT_CALL_SHORT_PRESS_KEY_UP;
    public static final int KEY_EVENT_VOICE_SEARCH_KEY_DOWN;
    public static final int KEY_EVENT_VOICE_SEARCH_LONG_PRESS_KEY_DOWN;
    public static final int KEY_EVENT_VOICE_SEARCH_LONG_PRESS_KEY_UP;
    public static final int KEY_EVENT_VOICE_SEARCH_SHORT_PRESS_KEY_UP;
    public static final int NUM_KEY_EVENTS;
    public static final int PROJECTION_AP_FAILED;
    public static final int PROJECTION_AP_STARTED;
    public static final int PROJECTION_AP_STOPPED;
    public static final int PROJECTION_LONG_PRESS_VOICE_SEARCH;
    public static final int PROJECTION_VOICE_SEARCH;
    private static final String TAG;
    private static final IBinder mAccessPointProxyToken = new Binder();
    private final ICarProjectionKeyEventHandlerImpl mBinderHandler = new ICarProjectionKeyEventHandlerImpl();
    private CarProjectionStatusListenerImpl mCarProjectionStatusListener;
    private BitSet mHandledEvents = new BitSet();
    private final Executor mHandlerExecutor;
    private final Map<ProjectionKeyEventHandler, KeyEventHandlerRecord> mKeyEventHandlers = new HashMap();
    private final ProjectionKeyEventHandler mLegacyListenerTranslator = new ProjectionKeyEventHandler() {
        /* class android.car.$$Lambda$CarProjectionManager$Jd_nLIhNaQPyVBtXf8qp9HIusSE */

        @Override // android.car.CarProjectionManager.ProjectionKeyEventHandler
        public final void onKeyEvent(int i) {
            CarProjectionManager.lambda$Jd_nLIhNaQPyVBtXf8qp9HIusSE(CarProjectionManager.this, i);
        }
    };
    private CarProjectionListener mListener;
    private final Object mLock = new Object();
    private ProjectionAccessPointCallbackProxy mProjectionAccessPointCallbackProxy;
    private final Set<ProjectionStatusListener> mProjectionStatusListeners = new LinkedHashSet();
    private final ICarProjection mService;
    private final Binder mToken = new Binder();
    private int mVoiceSearchFilter;

    public interface CarProjectionListener {
        void onVoiceAssistantRequest(boolean z);
    }

    public @interface KeyEventNum {
    }

    public interface ProjectionKeyEventHandler {
        void onKeyEvent(int i);
    }

    public interface ProjectionStatusListener {
        void onProjectionStatusChanged(int i, String str, List<ProjectionStatus> list);
    }

    @Override // android.car.CarManagerBase
    public void onCarDisconnected() {
    }

    public CarProjectionManager(Car car, IBinder iBinder) {
        super(car);
        this.mService = ICarProjection.Stub.asInterface(iBinder);
        Handler eventHandler = getEventHandler();
        Objects.requireNonNull(eventHandler);
        this.mHandlerExecutor = new Executor(eventHandler) {
            /* class android.car.$$Lambda$CarProjectionManager$xMC8M6LLEeW997bBmO6BCC6GGAM */
            public final /* synthetic */ Handler f$0;

            {
                this.f$0 = r1;
            }

            public final void execute(Runnable runnable) {
                CarProjectionManager.lambda$xMC8M6LLEeW997bBmO6BCC6GGAM(this.f$0, runnable);
            }
        };
    }

    public void regsiterProjectionListener(CarProjectionListener carProjectionListener, int i) {
        registerProjectionListener(carProjectionListener, i);
    }

    public void registerProjectionListener(CarProjectionListener carProjectionListener, int i) {
        Objects.requireNonNull(carProjectionListener, "listener cannot be null");
        synchronized (this.mLock) {
            if (this.mListener == null || this.mVoiceSearchFilter != i) {
                addKeyEventHandler(translateVoiceSearchFilter(i), this.mLegacyListenerTranslator);
            }
            this.mListener = carProjectionListener;
            this.mVoiceSearchFilter = i;
        }
    }

    public void unregsiterProjectionListener() {
        unregisterProjectionListener();
    }

    public void unregisterProjectionListener() {
        synchronized (this.mLock) {
            removeKeyEventHandler(this.mLegacyListenerTranslator);
            this.mListener = null;
            this.mVoiceSearchFilter = 0;
        }
    }

    private static Set<Integer> translateVoiceSearchFilter(int i) {
        ArraySet arraySet = new ArraySet(Integer.bitCount(i));
        if ((i & 1) != 0) {
            arraySet.add(1);
        }
        if ((i & 2) != 0) {
            arraySet.add(2);
        }
        return arraySet;
    }

    /* access modifiers changed from: public */
    private void translateKeyEventToLegacyListener(int i) {
        synchronized (this.mLock) {
            CarProjectionListener carProjectionListener = this.mListener;
            if (carProjectionListener != null) {
                boolean z = true;
                if (i == 1) {
                    z = false;
                } else if (i != 2) {
                    Log.e(TAG, "Unexpected key event " + i);
                    return;
                }
                Log.d(TAG, "Voice assistant request, long-press = " + z);
                carProjectionListener.onVoiceAssistantRequest(z);
            }
        }
    }

    public void addKeyEventHandler(Set<Integer> set, ProjectionKeyEventHandler projectionKeyEventHandler) {
        addKeyEventHandler(set, null, projectionKeyEventHandler);
    }

    public void addKeyEventHandler(Set<Integer> set, Executor executor, ProjectionKeyEventHandler projectionKeyEventHandler) {
        BitSet bitSet = new BitSet();
        for (Integer num : set) {
            int intValue = num.intValue();
            Preconditions.checkArgument(intValue >= 0 && intValue < 8, "Invalid key event");
            bitSet.set(intValue);
        }
        if (bitSet.isEmpty()) {
            removeKeyEventHandler(projectionKeyEventHandler);
            return;
        }
        if (executor == null) {
            executor = this.mHandlerExecutor;
        }
        synchronized (this.mLock) {
            KeyEventHandlerRecord keyEventHandlerRecord = this.mKeyEventHandlers.get(projectionKeyEventHandler);
            if (keyEventHandlerRecord == null) {
                this.mKeyEventHandlers.put(projectionKeyEventHandler, new KeyEventHandlerRecord(executor, bitSet));
            } else {
                keyEventHandlerRecord.mExecutor = executor;
                keyEventHandlerRecord.mSubscribedEvents = bitSet;
            }
            updateHandledEventsLocked();
        }
    }

    public void removeKeyEventHandler(ProjectionKeyEventHandler projectionKeyEventHandler) {
        synchronized (this.mLock) {
            if (this.mKeyEventHandlers.remove(projectionKeyEventHandler) != null) {
                updateHandledEventsLocked();
            }
        }
    }

    private void updateHandledEventsLocked() {
        BitSet bitSet = new BitSet();
        for (KeyEventHandlerRecord keyEventHandlerRecord : this.mKeyEventHandlers.values()) {
            bitSet.or(keyEventHandlerRecord.mSubscribedEvents);
        }
        if (!bitSet.equals(this.mHandledEvents)) {
            try {
                if (!bitSet.isEmpty()) {
                    Log.d(TAG, "Registering handler with system for " + bitSet);
                    this.mService.registerKeyEventHandler(this.mBinderHandler, bitSet.toByteArray());
                } else {
                    Log.d(TAG, "Unregistering handler with system");
                    this.mService.unregisterKeyEventHandler(this.mBinderHandler);
                }
                this.mHandledEvents = bitSet;
            } catch (RemoteException e) {
                handleRemoteExceptionFromCarService(e);
            }
        }
    }

    public void registerProjectionRunner(Intent intent) {
        Objects.requireNonNull("serviceIntent cannot be null");
        synchronized (this.mLock) {
            try {
                this.mService.registerProjectionRunner(intent);
            } catch (RemoteException e) {
                handleRemoteExceptionFromCarService(e);
            }
        }
    }

    public void unregisterProjectionRunner(Intent intent) {
        Objects.requireNonNull("serviceIntent cannot be null");
        synchronized (this.mLock) {
            try {
                this.mService.unregisterProjectionRunner(intent);
            } catch (RemoteException e) {
                handleRemoteExceptionFromCarService(e);
            }
        }
    }

    public void startProjectionAccessPoint(ProjectionAccessPointCallback projectionAccessPointCallback) {
        Objects.requireNonNull(projectionAccessPointCallback, "callback cannot be null");
        synchronized (this.mLock) {
            ProjectionAccessPointCallbackProxy projectionAccessPointCallbackProxy = new ProjectionAccessPointCallbackProxy(this, getEventHandler().getLooper(), projectionAccessPointCallback);
            try {
                this.mService.startProjectionAccessPoint(projectionAccessPointCallbackProxy.getMessenger(), mAccessPointProxyToken);
                this.mProjectionAccessPointCallbackProxy = projectionAccessPointCallbackProxy;
            } catch (RemoteException e) {
                handleRemoteExceptionFromCarService(e);
            }
        }
    }

    public List<Integer> getAvailableWifiChannels(int i) {
        try {
            int[] availableWifiChannels = this.mService.getAvailableWifiChannels(i);
            ArrayList arrayList = new ArrayList(availableWifiChannels.length);
            for (int i2 : availableWifiChannels) {
                arrayList.add(Integer.valueOf(i2));
            }
            return arrayList;
        } catch (RemoteException e) {
            return (List) handleRemoteExceptionFromCarService(e, Collections.emptyList());
        }
    }

    public void stopProjectionAccessPoint() {
        ProjectionAccessPointCallbackProxy projectionAccessPointCallbackProxy;
        synchronized (this.mLock) {
            projectionAccessPointCallbackProxy = this.mProjectionAccessPointCallbackProxy;
            this.mProjectionAccessPointCallbackProxy = null;
        }
        if (projectionAccessPointCallbackProxy != null) {
            try {
                this.mService.stopProjectionAccessPoint(mAccessPointProxyToken);
            } catch (RemoteException e) {
                handleRemoteExceptionFromCarService(e);
            }
        }
    }

    public boolean requestBluetoothProfileInhibit(BluetoothDevice bluetoothDevice, int i) {
        Objects.requireNonNull(bluetoothDevice, "device cannot be null");
        try {
            return this.mService.requestBluetoothProfileInhibit(bluetoothDevice, i, this.mToken);
        } catch (RemoteException e) {
            return ((Boolean) handleRemoteExceptionFromCarService(e, false)).booleanValue();
        }
    }

    public boolean releaseBluetoothProfileInhibit(BluetoothDevice bluetoothDevice, int i) {
        Objects.requireNonNull(bluetoothDevice, "device cannot be null");
        try {
            return this.mService.releaseBluetoothProfileInhibit(bluetoothDevice, i, this.mToken);
        } catch (RemoteException e) {
            return ((Boolean) handleRemoteExceptionFromCarService(e, false)).booleanValue();
        }
    }

    public void updateProjectionStatus(ProjectionStatus projectionStatus) {
        Objects.requireNonNull(projectionStatus, "status cannot be null");
        try {
            this.mService.updateProjectionStatus(projectionStatus, this.mToken);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    public void registerProjectionStatusListener(ProjectionStatusListener projectionStatusListener) {
        Objects.requireNonNull(projectionStatusListener, "listener cannot be null");
        synchronized (this.mLock) {
            this.mProjectionStatusListeners.add(projectionStatusListener);
            if (this.mCarProjectionStatusListener == null) {
                CarProjectionStatusListenerImpl carProjectionStatusListenerImpl = new CarProjectionStatusListenerImpl();
                this.mCarProjectionStatusListener = carProjectionStatusListenerImpl;
                try {
                    this.mService.registerProjectionStatusListener(carProjectionStatusListenerImpl);
                } catch (RemoteException e) {
                    handleRemoteExceptionFromCarService(e);
                }
            } else {
                getEventHandler().post(new Runnable(projectionStatusListener) {
                    /* class android.car.$$Lambda$CarProjectionManager$jZjnlnLCFF7ZIIfTH1XRTbAnUtY */
                    public final /* synthetic */ CarProjectionManager.ProjectionStatusListener f$1;

                    {
                        this.f$1 = r2;
                    }

                    public final void run() {
                        CarProjectionManager.this.lambda$registerProjectionStatusListener$0$CarProjectionManager(this.f$1);
                    }
                });
            }
        }
    }

    public /* synthetic */ void lambda$registerProjectionStatusListener$0$CarProjectionManager(ProjectionStatusListener projectionStatusListener) {
        projectionStatusListener.onProjectionStatusChanged(this.mCarProjectionStatusListener.mCurrentState, this.mCarProjectionStatusListener.mCurrentPackageName, this.mCarProjectionStatusListener.mDetails);
    }

    public void unregisterProjectionStatusListener(ProjectionStatusListener projectionStatusListener) {
        Objects.requireNonNull(projectionStatusListener, "listener cannot be null");
        synchronized (this.mLock) {
            if (this.mProjectionStatusListeners.remove(projectionStatusListener)) {
                if (this.mProjectionStatusListeners.isEmpty()) {
                    unregisterProjectionStatusListenerFromCarServiceLocked();
                }
            }
        }
    }

    private void unregisterProjectionStatusListenerFromCarServiceLocked() {
        try {
            this.mService.unregisterProjectionStatusListener(this.mCarProjectionStatusListener);
            this.mCarProjectionStatusListener = null;
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    private void handleProjectionStatusChanged(int i, String str, List<ProjectionStatus> list) {
        ArrayList<ProjectionStatusListener> arrayList;
        synchronized (this.mLock) {
            arrayList = new ArrayList(this.mProjectionStatusListeners);
        }
        for (ProjectionStatusListener projectionStatusListener : arrayList) {
            projectionStatusListener.onProjectionStatusChanged(i, str, list);
        }
    }

    public Bundle getProjectionOptions() {
        try {
            return this.mService.getProjectionOptions();
        } catch (RemoteException e) {
            return (Bundle) handleRemoteExceptionFromCarService(e, Bundle.EMPTY);
        }
    }

    public static abstract class ProjectionAccessPointCallback {
        public static final int ERROR_GENERIC;
        public static final int ERROR_INCOMPATIBLE_MODE;
        public static final int ERROR_NO_CHANNEL;
        public static final int ERROR_TETHERING_DISALLOWED;

        public void onFailed(int i) {
        }

        public void onStarted(WifiConfiguration wifiConfiguration) {
        }

        public void onStopped() {
        }

        public void onStarted(SoftApConfiguration softApConfiguration) {
            onStarted(softApConfiguration.toWifiConfiguration());
        }
    }

    /* access modifiers changed from: private */
    public static class ProjectionAccessPointCallbackProxy {
        private static final String LOG_PREFIX = (ProjectionAccessPointCallbackProxy.class.getSimpleName() + ": ");
        private final WeakReference<CarProjectionManager> mCarProjectionManagerRef;
        private final Handler mHandler;
        private final Messenger mMessenger;

        ProjectionAccessPointCallbackProxy(CarProjectionManager carProjectionManager, Looper looper, final ProjectionAccessPointCallback projectionAccessPointCallback) {
            this.mCarProjectionManagerRef = new WeakReference<>(carProjectionManager);
            AnonymousClass1 r2 = new Handler(looper) {
                /* class android.car.CarProjectionManager.ProjectionAccessPointCallbackProxy.AnonymousClass1 */

                public void handleMessage(Message message) {
                    Log.d(CarProjectionManager.TAG, ProjectionAccessPointCallbackProxy.LOG_PREFIX + "handle message what: " + message.what + " msg: " + message);
                    if (((CarProjectionManager) ProjectionAccessPointCallbackProxy.this.mCarProjectionManagerRef.get()) == null) {
                        Log.w(CarProjectionManager.TAG, ProjectionAccessPointCallbackProxy.LOG_PREFIX + "handle message post GC");
                        return;
                    }
                    int i = message.what;
                    if (i == 0) {
                        SoftApConfiguration softApConfiguration = (SoftApConfiguration) message.obj;
                        if (softApConfiguration == null) {
                            Log.e(CarProjectionManager.TAG, ProjectionAccessPointCallbackProxy.LOG_PREFIX + "config cannot be null.");
                            projectionAccessPointCallback.onFailed(2);
                            return;
                        }
                        projectionAccessPointCallback.onStarted(softApConfiguration);
                    } else if (i == 1) {
                        Log.i(CarProjectionManager.TAG, ProjectionAccessPointCallbackProxy.LOG_PREFIX + "hotspot stopped");
                        projectionAccessPointCallback.onStopped();
                    } else if (i != 2) {
                        Log.e(CarProjectionManager.TAG, ProjectionAccessPointCallbackProxy.LOG_PREFIX + "unhandled message.  type: " + message.what);
                    } else {
                        int i2 = message.arg1;
                        Log.w(CarProjectionManager.TAG, ProjectionAccessPointCallbackProxy.LOG_PREFIX + "failed to start.  reason: " + i2);
                        projectionAccessPointCallback.onFailed(i2);
                    }
                }
            };
            this.mHandler = r2;
            this.mMessenger = new Messenger(r2);
        }

        public Messenger getMessenger() {
            return this.mMessenger;
        }
    }

    public static class ICarProjectionKeyEventHandlerImpl extends ICarProjectionKeyEventHandler.Stub {
        private final WeakReference<CarProjectionManager> mManager;

        private ICarProjectionKeyEventHandlerImpl(CarProjectionManager carProjectionManager) {
            this.mManager = new WeakReference<>(carProjectionManager);
        }

        @Override // android.car.ICarProjectionKeyEventHandler
        public void onKeyEvent(int i) {
            Log.d(CarProjectionManager.TAG, "Received projection key event " + i);
            CarProjectionManager carProjectionManager = this.mManager.get();
            if (carProjectionManager != null) {
                ArrayList<Pair> arrayList = new ArrayList();
                synchronized (carProjectionManager.mLock) {
                    for (Map.Entry entry : carProjectionManager.mKeyEventHandlers.entrySet()) {
                        if (((KeyEventHandlerRecord) entry.getValue()).mSubscribedEvents.get(i)) {
                            arrayList.add(Pair.create((ProjectionKeyEventHandler) entry.getKey(), ((KeyEventHandlerRecord) entry.getValue()).mExecutor));
                        }
                    }
                }
                for (Pair pair : arrayList) {
                    ((Executor) pair.second).execute(new Runnable(i) {
                        /* class android.car.$$Lambda$CarProjectionManager$ICarProjectionKeyEventHandlerImpl$nzAOlP6hkyRuHWQF3qb2Tuzaak */
                        public final /* synthetic */ int f$1;

                        {
                            this.f$1 = r2;
                        }

                        public final void run() {
                            CarProjectionManager.ICarProjectionKeyEventHandlerImpl.lambda$onKeyEvent$0(CarProjectionManager.ProjectionKeyEventHandler.this, this.f$1);
                        }
                    });
                }
            }
        }
    }

    public static class KeyEventHandlerRecord {
        Executor mExecutor;
        BitSet mSubscribedEvents;

        KeyEventHandlerRecord(Executor executor, BitSet bitSet) {
            this.mExecutor = executor;
            this.mSubscribedEvents = bitSet;
        }
    }

    public static class CarProjectionStatusListenerImpl extends ICarProjectionStatusListener.Stub {
        private String mCurrentPackageName;
        private int mCurrentState;
        private List<ProjectionStatus> mDetails;
        private final WeakReference<CarProjectionManager> mManagerRef;

        private CarProjectionStatusListenerImpl(CarProjectionManager carProjectionManager) {
            this.mDetails = new ArrayList(0);
            this.mManagerRef = new WeakReference<>(carProjectionManager);
        }

        @Override // android.car.ICarProjectionStatusListener
        public void onProjectionStatusChanged(int i, String str, List<ProjectionStatus> list) {
            CarProjectionManager carProjectionManager = this.mManagerRef.get();
            if (carProjectionManager != null) {
                carProjectionManager.getEventHandler().post(new Runnable(i, str, list, carProjectionManager) {
                    /* class android.car.$$Lambda$CarProjectionManager$CarProjectionStatusListenerImpl$qiO02l6tb6NTG0q2kld7Xcnnak0 */
                    public final /* synthetic */ int f$1;
                    public final /* synthetic */ String f$2;
                    public final /* synthetic */ List f$3;
                    public final /* synthetic */ CarProjectionManager f$4;

                    {
                        this.f$1 = r2;
                        this.f$2 = r3;
                        this.f$3 = r4;
                        this.f$4 = r5;
                    }

                    public final void run() {
                        CarProjectionManager.CarProjectionStatusListenerImpl.this.lambda$onProjectionStatusChanged$0$CarProjectionManager$CarProjectionStatusListenerImpl(this.f$1, this.f$2, this.f$3, this.f$4);
                    }
                });
            }
        }

        public /* synthetic */ void lambda$onProjectionStatusChanged$0$CarProjectionManager$CarProjectionStatusListenerImpl(int i, String str, List list, CarProjectionManager carProjectionManager) {
            this.mCurrentState = i;
            this.mCurrentPackageName = str;
            List<ProjectionStatus> unmodifiableList = Collections.unmodifiableList(list);
            this.mDetails = unmodifiableList;
            carProjectionManager.handleProjectionStatusChanged(i, str, unmodifiableList);
        }
    }
}
