package android.car.cluster.renderer;

import android.annotation.SystemApi;
import android.app.ActivityOptions;
import android.app.Service;
import android.car.Car;
import android.car.cluster.ClusterActivityState;
import android.car.cluster.renderer.IInstrumentCluster;
import android.car.cluster.renderer.IInstrumentClusterHelper;
import android.car.cluster.renderer.IInstrumentClusterNavigation;
import android.car.cluster.renderer.InstrumentClusterRenderingService;
import android.car.navigation.CarNavigationInstrumentCluster;
import android.content.ActivityNotFoundException;
import android.content.ComponentName;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.content.pm.ProviderInfo;
import android.content.pm.ResolveInfo;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper;
import android.os.ParcelFileDescriptor;
import android.os.RemoteException;
import android.os.UserHandle;
import android.util.Log;
import android.util.LruCache;
import android.view.KeyEvent;
import java.io.FileDescriptor;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashSet;
import java.util.List;
import java.util.Objects;
import java.util.Set;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.atomic.AtomicReference;
import java.util.function.Function;
import java.util.function.Supplier;
import java.util.stream.Collectors;

@SystemApi
public abstract class InstrumentClusterRenderingService extends Service {
    private static final String BITMAP_QUERY_HEIGHT = "h";
    private static final String BITMAP_QUERY_OFFLANESALPHA = "offLanesAlpha";
    private static final String BITMAP_QUERY_WIDTH = "w";
    public static final String EXTRA_BUNDLE_KEY_FOR_INSTRUMENT_CLUSTER_HELPER = "android.car.cluster.renderer.IInstrumentClusterHelper";
    private static final int IMAGE_CACHE_SIZE_BYTES = 4194304;
    private static final String TAG = "CAR.L.CLUSTER";
    private ActivityOptions mActivityOptions;
    private ClusterActivityState mActivityState;
    private final LruCache<String, Bitmap> mCache = new LruCache<String, Bitmap>(4194304) {
        /* class android.car.cluster.renderer.InstrumentClusterRenderingService.AnonymousClass1 */

        /* access modifiers changed from: protected */
        public int sizeOf(String str, Bitmap bitmap) {
            return bitmap.getByteCount();
        }
    };
    private IInstrumentClusterHelper mInstrumentClusterHelper;
    private final Object mLock = new Object();
    private ContextOwner mNavContextOwner;
    private ComponentName mNavigationComponent;
    private RendererBinder mRendererBinder;
    private final Handler mUiHandler = new Handler(Looper.getMainLooper());

    public abstract NavigationRenderer getNavigationRenderer();

    public void onKeyEvent(KeyEvent keyEvent) {
    }

    public void onNavigationComponentLaunched() {
    }

    public void onNavigationComponentReleased() {
    }

    /* access modifiers changed from: private */
    public static class ContextOwner {
        final Set<String> mAuthorities;
        final Set<String> mPackageNames;
        final int mPid;
        final int mUid;

        ContextOwner(int i, int i2, PackageManager packageManager) {
            Set<String> set;
            this.mUid = i;
            this.mPid = i2;
            String[] packagesForUid = i != 0 ? packageManager.getPackagesForUid(i) : null;
            if (packagesForUid != null) {
                set = Collections.unmodifiableSet(new HashSet(Arrays.asList(packagesForUid)));
            } else {
                set = Collections.emptySet();
            }
            this.mPackageNames = set;
            this.mAuthorities = Collections.unmodifiableSet((Set) set.stream().map(new Function(packageManager) {
                /* class android.car.cluster.renderer.$$Lambda$InstrumentClusterRenderingService$ContextOwner$IUGyug9p15P5lahfMpiZjuqnB3g */
                public final /* synthetic */ PackageManager f$1;

                {
                    this.f$1 = r2;
                }

                @Override // java.util.function.Function
                public final Object apply(Object obj) {
                    return InstrumentClusterRenderingService.ContextOwner.this.lambda$new$0$InstrumentClusterRenderingService$ContextOwner(this.f$1, (String) obj);
                }
            }).flatMap($$Lambda$2uajARPg7zs3QXdN3ekutEAqAgM.INSTANCE).collect(Collectors.toSet()));
        }

        public String toString() {
            return "{uid: " + this.mUid + ", pid: " + this.mPid + ", packagenames: " + this.mPackageNames + ", authorities: " + this.mAuthorities + "}";
        }

        /* access modifiers changed from: private */
        /* renamed from: getAuthoritiesForPackage */
        public List<String> lambda$new$0$InstrumentClusterRenderingService$ContextOwner(PackageManager packageManager, String str) {
            try {
                ProviderInfo[] providerInfoArr = packageManager.getPackageInfo(str, 8).providers;
                if (providerInfoArr == null) {
                    return Collections.emptyList();
                }
                return (List) Arrays.stream(providerInfoArr).map($$Lambda$InstrumentClusterRenderingService$ContextOwner$1wwVLC3uGT9Kdgzeo2I0PgoXEUM.INSTANCE).collect(Collectors.toList());
            } catch (PackageManager.NameNotFoundException unused) {
                Log.w("CAR.L.CLUSTER", "Package name not found while retrieving content provider authorities: " + str);
                return Collections.emptyList();
            }
        }
    }

    public IBinder onBind(Intent intent) {
        if (Log.isLoggable("CAR.L.CLUSTER", 3)) {
            Log.d("CAR.L.CLUSTER", "onBind, intent: " + intent);
        }
        Bundle bundleExtra = intent.getBundleExtra(EXTRA_BUNDLE_KEY_FOR_INSTRUMENT_CLUSTER_HELPER);
        IBinder iBinder = null;
        if (bundleExtra != null) {
            iBinder = bundleExtra.getBinder(EXTRA_BUNDLE_KEY_FOR_INSTRUMENT_CLUSTER_HELPER);
        }
        if (iBinder == null) {
            Log.wtf("CAR.L.CLUSTER", "IInstrumentClusterHelper not passed through binder");
        } else {
            synchronized (this.mLock) {
                this.mInstrumentClusterHelper = IInstrumentClusterHelper.Stub.asInterface(iBinder);
            }
        }
        if (this.mRendererBinder == null) {
            this.mRendererBinder = new RendererBinder(getNavigationRenderer());
        }
        return this.mRendererBinder;
    }

    private IInstrumentClusterHelper getClusterHelper() {
        IInstrumentClusterHelper iInstrumentClusterHelper;
        synchronized (this.mLock) {
            if (this.mInstrumentClusterHelper == null) {
                Log.w("mInstrumentClusterHelper still null, should wait until onBind", new RuntimeException());
            }
            iInstrumentClusterHelper = this.mInstrumentClusterHelper;
        }
        return iInstrumentClusterHelper;
    }

    public boolean startFixedActivityModeForDisplayAndUser(Intent intent, ActivityOptions activityOptions, int i) {
        IInstrumentClusterHelper clusterHelper = getClusterHelper();
        if (clusterHelper == null) {
            return false;
        }
        if (this.mActivityState != null && intent.getBundleExtra("android.car.cluster.ClusterActivityState") == null) {
            intent = new Intent(intent).putExtra("android.car.cluster.ClusterActivityState", this.mActivityState.toBundle());
        }
        try {
            return clusterHelper.startFixedActivityModeForDisplayAndUser(intent, activityOptions.toBundle(), i);
        } catch (RemoteException e) {
            Log.w("Remote exception from car service", e);
            return false;
        }
    }

    public void stopFixedActivityMode(int i) {
        IInstrumentClusterHelper clusterHelper = getClusterHelper();
        if (clusterHelper != null) {
            try {
                clusterHelper.stopFixedActivityMode(i);
            } catch (RemoteException e) {
                Log.w("Remote exception from car service, displayId:" + i, e);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateNavigationActivity() {
        ClusterActivityState clusterActivityState;
        ContextOwner navigationContextOwner = getNavigationContextOwner();
        if (Log.isLoggable("CAR.L.CLUSTER", 3)) {
            Log.d("CAR.L.CLUSTER", String.format("updateNavigationActivity (mActivityOptions: %s, mActivityState: %s, mNavContextOwnerUid: %s)", this.mActivityOptions, this.mActivityState, navigationContextOwner));
        }
        if (navigationContextOwner != null && navigationContextOwner.mUid != 0 && this.mActivityOptions != null && (clusterActivityState = this.mActivityState) != null && clusterActivityState.isVisible()) {
            ComponentName navigationComponentByOwner = getNavigationComponentByOwner(navigationContextOwner);
            if (Objects.equals(this.mNavigationComponent, navigationComponentByOwner)) {
                if (Log.isLoggable("CAR.L.CLUSTER", 3)) {
                    Log.d("CAR.L.CLUSTER", "Already launched component: " + navigationComponentByOwner);
                }
            } else if (navigationComponentByOwner == null) {
                if (Log.isLoggable("CAR.L.CLUSTER", 3)) {
                    Log.d("CAR.L.CLUSTER", "No component found for owner: " + navigationContextOwner);
                }
            } else if (startNavigationActivity(navigationComponentByOwner)) {
                this.mNavigationComponent = navigationComponentByOwner;
                onNavigationComponentLaunched();
            } else if (Log.isLoggable("CAR.L.CLUSTER", 3)) {
                Log.d("CAR.L.CLUSTER", "Unable to launch component: " + navigationComponentByOwner);
            }
        } else if (this.mNavigationComponent != null) {
            this.mNavigationComponent = null;
            onNavigationComponentReleased();
        }
    }

    private ComponentName getNavigationComponentByOwner(ContextOwner contextOwner) {
        for (String str : contextOwner.mPackageNames) {
            ComponentName componentFromPackage = getComponentFromPackage(str);
            if (componentFromPackage != null) {
                if (Log.isLoggable("CAR.L.CLUSTER", 3)) {
                    Log.d("CAR.L.CLUSTER", "Found component: " + componentFromPackage);
                }
                return componentFromPackage;
            }
        }
        return null;
    }

    private ContextOwner getNavigationContextOwner() {
        ContextOwner contextOwner;
        synchronized (this.mLock) {
            contextOwner = this.mNavContextOwner;
        }
        return contextOwner;
    }

    private ComponentName getComponentFromPackage(String str) {
        PackageManager packageManager = getPackageManager();
        if (packageManager.checkPermission(Car.PERMISSION_CAR_DISPLAY_IN_CLUSTER, str) != 0) {
            Log.i("CAR.L.CLUSTER", String.format("Package '%s' doesn't have permission %s", str, Car.PERMISSION_CAR_DISPLAY_IN_CLUSTER));
            return null;
        }
        Intent intent = new Intent("android.intent.action.MAIN").addCategory("android.car.cluster.NAVIGATION").setPackage(str);
        List<ResolveInfo> queryIntentActivities = packageManager.queryIntentActivities(intent, 64);
        if (queryIntentActivities != null && !queryIntentActivities.isEmpty() && queryIntentActivities.get(0).getComponentInfo() != null) {
            return queryIntentActivities.get(0).getComponentInfo().getComponentName();
        }
        Log.i("CAR.L.CLUSTER", "Failed to resolve an intent: " + intent);
        return null;
    }

    /* access modifiers changed from: protected */
    public boolean startNavigationActivity(ComponentName componentName) {
        Intent intent = new Intent();
        intent.setComponent(componentName);
        intent.putExtra("android.car.cluster.ClusterActivityState", this.mActivityState.toBundle());
        intent.addFlags(268435456);
        try {
            startActivityAsUser(intent, this.mActivityOptions.toBundle(), UserHandle.CURRENT);
            ActivityOptions activityOptions = this.mActivityOptions;
            Log.i("CAR.L.CLUSTER", String.format("Activity launched: %s (options: %s, displayId: %d)", activityOptions, intent, Integer.valueOf(activityOptions.getLaunchDisplayId())));
            return true;
        } catch (ActivityNotFoundException unused) {
            Log.w("CAR.L.CLUSTER", "Unable to find activity for intent: " + intent);
            return false;
        } catch (RuntimeException e) {
            Log.e("CAR.L.CLUSTER", "Error trying to launch intent: " + intent + ". Ignored", e);
            return false;
        }
    }

    @Deprecated
    public void setClusterActivityLaunchOptions(String str, ActivityOptions activityOptions) {
        setClusterActivityLaunchOptions(activityOptions);
    }

    public void setClusterActivityLaunchOptions(ActivityOptions activityOptions) {
        this.mActivityOptions = activityOptions;
        updateNavigationActivity();
    }

    @Deprecated
    public void setClusterActivityState(String str, Bundle bundle) {
        setClusterActivityState(ClusterActivityState.fromBundle(bundle));
    }

    public void setClusterActivityState(ClusterActivityState clusterActivityState) {
        this.mActivityState = clusterActivityState;
        updateNavigationActivity();
    }

    /* access modifiers changed from: protected */
    public void dump(FileDescriptor fileDescriptor, PrintWriter printWriter, String[] strArr) {
        synchronized (this.mLock) {
            printWriter.println("**" + getClass().getSimpleName() + "**");
            printWriter.println("renderer binder: " + this.mRendererBinder);
            if (this.mRendererBinder != null) {
                printWriter.println("navigation renderer: " + this.mRendererBinder.mNavigationRenderer);
            }
            printWriter.println("navigation focus owner: " + getNavigationContextOwner());
            printWriter.println("activity options: " + this.mActivityOptions);
            printWriter.println("activity state: " + this.mActivityState);
            printWriter.println("current nav component: " + this.mNavigationComponent);
            printWriter.println("current nav packages: " + getNavigationContextOwner().mPackageNames);
            printWriter.println("mInstrumentClusterHelper" + this.mInstrumentClusterHelper);
        }
    }

    /* access modifiers changed from: private */
    public class RendererBinder extends IInstrumentCluster.Stub {
        private final NavigationRenderer mNavigationRenderer;

        RendererBinder(NavigationRenderer navigationRenderer) {
            this.mNavigationRenderer = navigationRenderer;
        }

        @Override // android.car.cluster.renderer.IInstrumentCluster
        public IInstrumentClusterNavigation getNavigationService() throws RemoteException {
            return new NavigationBinder(this.mNavigationRenderer);
        }

        @Override // android.car.cluster.renderer.IInstrumentCluster
        public void setNavigationContextOwner(int i, int i2) throws RemoteException {
            if (Log.isLoggable("CAR.L.CLUSTER", 3)) {
                Log.d("CAR.L.CLUSTER", "Updating navigation ownership to uid: " + i + ", pid: " + i2);
            }
            synchronized (InstrumentClusterRenderingService.this.mLock) {
                InstrumentClusterRenderingService.this.mNavContextOwner = new ContextOwner(i, i2, InstrumentClusterRenderingService.this.getPackageManager());
            }
            InstrumentClusterRenderingService.this.mUiHandler.post(new Runnable() {
                /* class android.car.cluster.renderer.$$Lambda$InstrumentClusterRenderingService$RendererBinder$AgWDXsUL0vXE2aLA5rmfEJITOQw */

                public final void run() {
                    InstrumentClusterRenderingService.access$400(InstrumentClusterRenderingService.this);
                }
            });
        }

        public /* synthetic */ void lambda$onKeyEvent$1$InstrumentClusterRenderingService$RendererBinder(KeyEvent keyEvent) {
            InstrumentClusterRenderingService.this.onKeyEvent(keyEvent);
        }

        @Override // android.car.cluster.renderer.IInstrumentCluster
        public void onKeyEvent(KeyEvent keyEvent) throws RemoteException {
            InstrumentClusterRenderingService.this.mUiHandler.post(new Runnable(keyEvent) {
                /* class android.car.cluster.renderer.$$Lambda$InstrumentClusterRenderingService$RendererBinder$1Ng5pVKEq74yIZbm_mkiu7IlQFc */
                public final /* synthetic */ KeyEvent f$1;

                {
                    this.f$1 = r2;
                }

                public final void run() {
                    InstrumentClusterRenderingService.RendererBinder.this.lambda$onKeyEvent$1$InstrumentClusterRenderingService$RendererBinder(this.f$1);
                }
            });
        }
    }

    /* access modifiers changed from: private */
    public class NavigationBinder extends IInstrumentClusterNavigation.Stub {
        private final NavigationRenderer mNavigationRenderer;

        NavigationBinder(NavigationRenderer navigationRenderer) {
            this.mNavigationRenderer = navigationRenderer;
        }

        @Override // android.car.cluster.renderer.IInstrumentClusterNavigation
        public void onNavigationStateChanged(Bundle bundle) throws RemoteException {
            InstrumentClusterRenderingService.this.assertClusterManagerPermission();
            InstrumentClusterRenderingService.this.mUiHandler.post(new Runnable(bundle) {
                /* class android.car.cluster.renderer.$$Lambda$InstrumentClusterRenderingService$NavigationBinder$PkwU67SxNsVlbn7xeNC6YAdVEI */
                public final /* synthetic */ Bundle f$1;

                {
                    this.f$1 = r2;
                }

                public final void run() {
                    InstrumentClusterRenderingService.NavigationBinder.this.lambda$onNavigationStateChanged$0$InstrumentClusterRenderingService$NavigationBinder(this.f$1);
                }
            });
        }

        public /* synthetic */ void lambda$onNavigationStateChanged$0$InstrumentClusterRenderingService$NavigationBinder(Bundle bundle) {
            NavigationRenderer navigationRenderer = this.mNavigationRenderer;
            if (navigationRenderer != null) {
                navigationRenderer.onNavigationStateChanged(bundle);
            }
        }

        @Override // android.car.cluster.renderer.IInstrumentClusterNavigation
        public CarNavigationInstrumentCluster getInstrumentClusterInfo() throws RemoteException {
            InstrumentClusterRenderingService.this.assertClusterManagerPermission();
            return (CarNavigationInstrumentCluster) InstrumentClusterRenderingService.this.runAndWaitResult(new Supplier() {
                /* class android.car.cluster.renderer.$$Lambda$InstrumentClusterRenderingService$NavigationBinder$HL2HSz7do6jTcgZ2GGgfRf9hrME */

                @Override // java.util.function.Supplier
                public final Object get() {
                    return InstrumentClusterRenderingService.NavigationBinder.this.lambda$getInstrumentClusterInfo$1$InstrumentClusterRenderingService$NavigationBinder();
                }
            });
        }

        public /* synthetic */ CarNavigationInstrumentCluster lambda$getInstrumentClusterInfo$1$InstrumentClusterRenderingService$NavigationBinder() {
            return this.mNavigationRenderer.getNavigationProperties();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void assertClusterManagerPermission() {
        if (checkCallingOrSelfPermission(Car.PERMISSION_CAR_NAVIGATION_MANAGER) != 0) {
            throw new SecurityException("requires android.car.permission.CAR_NAVIGATION_MANAGER");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private <E> E runAndWaitResult(Supplier<E> supplier) {
        CountDownLatch countDownLatch = new CountDownLatch(1);
        AtomicReference atomicReference = new AtomicReference();
        this.mUiHandler.post(new Runnable(atomicReference, supplier, countDownLatch) {
            /* class android.car.cluster.renderer.$$Lambda$InstrumentClusterRenderingService$Zv7MhWrV78tqCUFVEBL5PsdMTdM */
            public final /* synthetic */ AtomicReference f$0;
            public final /* synthetic */ Supplier f$1;
            public final /* synthetic */ CountDownLatch f$2;

            {
                this.f$0 = r1;
                this.f$1 = r2;
                this.f$2 = r3;
            }

            public final void run() {
                InstrumentClusterRenderingService.lambda$runAndWaitResult$0(this.f$0, this.f$1, this.f$2);
            }
        });
        try {
            countDownLatch.await();
            return (E) atomicReference.get();
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
    }

    static /* synthetic */ void lambda$runAndWaitResult$0(AtomicReference atomicReference, Supplier supplier, CountDownLatch countDownLatch) {
        atomicReference.set(supplier.get());
        countDownLatch.countDown();
    }

    @Deprecated
    public Bitmap getBitmap(Uri uri) {
        try {
            if (uri.getQueryParameter(BITMAP_QUERY_WIDTH).isEmpty() || uri.getQueryParameter(BITMAP_QUERY_HEIGHT).isEmpty()) {
                throw new IllegalArgumentException("Uri must have 'w' and 'h' query parameters");
            }
            ContextOwner navigationContextOwner = getNavigationContextOwner();
            if (navigationContextOwner == null) {
                Log.e("CAR.L.CLUSTER", "No context owner available while fetching: " + uri);
                return null;
            }
            String host = uri.getHost();
            if (!navigationContextOwner.mAuthorities.contains(host)) {
                Log.e("CAR.L.CLUSTER", "Uri points to an authority not handled by the current context owner: " + uri + " (valid authorities: " + navigationContextOwner.mAuthorities + ")");
                return null;
            }
            Uri build = uri.buildUpon().encodedAuthority(UserHandle.getUserId(navigationContextOwner.mUid) + "@" + host).build();
            if (Log.isLoggable("CAR.L.CLUSTER", 3)) {
                Log.d("CAR.L.CLUSTER", "Requesting bitmap: " + uri);
            }
            ParcelFileDescriptor openFileDescriptor = getContentResolver().openFileDescriptor(build, "r");
            if (openFileDescriptor != null) {
                try {
                    Bitmap decodeFileDescriptor = BitmapFactory.decodeFileDescriptor(openFileDescriptor.getFileDescriptor());
                    if (openFileDescriptor != null) {
                        openFileDescriptor.close();
                    }
                    return decodeFileDescriptor;
                } catch (Throwable th) {
                    th.addSuppressed(th);
                }
            } else {
                Log.e("CAR.L.CLUSTER", "Failed to create pipe for uri string: " + uri);
                if (openFileDescriptor != null) {
                    openFileDescriptor.close();
                }
                return null;
            }
            throw th;
        } catch (IOException e) {
            Log.e("CAR.L.CLUSTER", "Unable to fetch uri: " + uri, e);
        }
    }

    public Bitmap getBitmap(Uri uri, int i, int i2) {
        return getBitmap(uri, i, i2, 1.0f);
    }

    public Bitmap getBitmap(Uri uri, int i, int i2, float f) {
        if (i <= 0 || i2 <= 0) {
            throw new IllegalArgumentException("Width and height must be > 0");
        } else if (f < 0.0f || f > 1.0f) {
            throw new IllegalArgumentException("offLanesAlpha must be between [0, 1]");
        } else {
            try {
                ContextOwner navigationContextOwner = getNavigationContextOwner();
                if (navigationContextOwner == null) {
                    Log.e("CAR.L.CLUSTER", "No context owner available while fetching: " + uri);
                    return null;
                }
                Uri build = uri.buildUpon().appendQueryParameter(BITMAP_QUERY_WIDTH, String.valueOf(i)).appendQueryParameter(BITMAP_QUERY_HEIGHT, String.valueOf(i2)).appendQueryParameter(BITMAP_QUERY_OFFLANESALPHA, String.valueOf(f)).build();
                String host = build.getHost();
                if (!navigationContextOwner.mAuthorities.contains(host)) {
                    Log.e("CAR.L.CLUSTER", "Uri points to an authority not handled by the current context owner: " + build + " (valid authorities: " + navigationContextOwner.mAuthorities + ")");
                    return null;
                }
                Uri build2 = build.buildUpon().encodedAuthority(UserHandle.getUserId(navigationContextOwner.mUid) + "@" + host).build();
                Bitmap bitmap = this.mCache.get(build.toString());
                if (bitmap == null) {
                    if (Log.isLoggable("CAR.L.CLUSTER", 3)) {
                        Log.d("CAR.L.CLUSTER", "Requesting bitmap: " + build);
                    }
                    ParcelFileDescriptor openFileDescriptor = getContentResolver().openFileDescriptor(build2, "r");
                    if (openFileDescriptor != null) {
                        try {
                            Bitmap decodeFileDescriptor = BitmapFactory.decodeFileDescriptor(openFileDescriptor.getFileDescriptor());
                            if (openFileDescriptor != null) {
                                openFileDescriptor.close();
                            }
                            return decodeFileDescriptor;
                        } catch (Throwable th) {
                            th.addSuppressed(th);
                        }
                    } else {
                        Log.e("CAR.L.CLUSTER", "Failed to create pipe for uri string: " + build);
                        if (openFileDescriptor != null) {
                            openFileDescriptor.close();
                        }
                        if (!(bitmap.getWidth() == i && bitmap.getHeight() == i2)) {
                            bitmap = Bitmap.createScaledBitmap(bitmap, i, i2, true);
                        }
                        this.mCache.put(build.toString(), bitmap);
                    }
                }
                return bitmap;
            } catch (IOException e) {
                Log.e("CAR.L.CLUSTER", "Unable to fetch uri: " + uri, e);
                return null;
            }
        }
        throw th;
    }
}
