package android.car.drivingstate;

import android.car.drivingstate.CarUxRestrictions;
import android.os.Build;
import android.os.Parcel;
import android.os.Parcelable;
import android.os.SystemClock;
import android.util.ArrayMap;
import android.util.JsonReader;
import android.util.JsonToken;
import android.util.JsonWriter;
import android.util.Log;
import java.io.CharArrayWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Objects;

public final class CarUxRestrictionsConfiguration implements Parcelable {
    public static final Parcelable.Creator<CarUxRestrictionsConfiguration> CREATOR = new Parcelable.Creator<CarUxRestrictionsConfiguration>() {
        /* class android.car.drivingstate.CarUxRestrictionsConfiguration.AnonymousClass1 */

        @Override // android.os.Parcelable.Creator
        public CarUxRestrictionsConfiguration createFromParcel(Parcel parcel) {
            return new CarUxRestrictionsConfiguration(parcel);
        }

        @Override // android.os.Parcelable.Creator
        public CarUxRestrictionsConfiguration[] newArray(int i) {
            return new CarUxRestrictionsConfiguration[i];
        }
    };
    private static final int[] DRIVING_STATES = {-1, 0, 1, 2};
    private static final String JSON_NAME_IDLING_RESTRICTIONS = "idling_restrictions";
    private static final String JSON_NAME_MAX_CONTENT_DEPTH = "max_content_depth";
    private static final String JSON_NAME_MAX_CUMULATIVE_CONTENT_ITEMS = "max_cumulative_content_items";
    private static final String JSON_NAME_MAX_SPEED = "max_speed";
    private static final String JSON_NAME_MAX_STRING_LENGTH = "max_string_length";
    private static final String JSON_NAME_MIN_SPEED = "min_speed";
    private static final String JSON_NAME_MOVING_RESTRICTIONS = "moving_restrictions";
    private static final String JSON_NAME_PARKED_RESTRICTIONS = "parked_restrictions";
    private static final String JSON_NAME_PHYSICAL_PORT = "physical_port";
    private static final String JSON_NAME_REQ_OPT = "req_opt";
    private static final String JSON_NAME_RESTRICTIONS = "restrictions";
    private static final String JSON_NAME_SPEED_RANGE = "speed_range";
    private static final String JSON_NAME_UNKNOWN_RESTRICTIONS = "unknown_restrictions";
    private static final String TAG = "CarUxRConfig";
    private final int mMaxContentDepth;
    private final int mMaxCumulativeContentItems;
    private final int mMaxStringLength;
    private final Byte mPhysicalPort;
    private final Map<String, RestrictionModeContainer> mRestrictionModes;

    private interface RestrictionConfigurationParser {
        void readJson(JsonReader jsonReader, String str, Builder builder) throws IOException;
    }

    public int describeContents() {
        return 0;
    }

    private CarUxRestrictionsConfiguration(Builder builder) {
        this.mRestrictionModes = new ArrayMap();
        this.mPhysicalPort = builder.mPhysicalPort;
        this.mMaxContentDepth = builder.mMaxContentDepth;
        this.mMaxCumulativeContentItems = builder.mMaxCumulativeContentItems;
        this.mMaxStringLength = builder.mMaxStringLength;
        for (Map.Entry<String, RestrictionModeContainer> entry : builder.mRestrictionModes.entrySet()) {
            String key = entry.getKey();
            RestrictionModeContainer restrictionModeContainer = new RestrictionModeContainer();
            int[] iArr = DRIVING_STATES;
            for (int i : iArr) {
                restrictionModeContainer.setRestrictionsForDriveState(i, Collections.unmodifiableList(entry.getValue().getRestrictionsForDriveState(i)));
            }
            this.mRestrictionModes.put(key, restrictionModeContainer);
        }
    }

    public CarUxRestrictions getUxRestrictions(int i, float f) {
        return getUxRestrictions(i, f, CarUxRestrictionsManager.UX_RESTRICTION_MODE_BASELINE);
    }

    public CarUxRestrictions getUxRestrictions(int i, float f, String str) {
        Objects.requireNonNull(str, "mode must not be null");
        RestrictionsPerSpeedRange findUxRestrictionsInList = this.mRestrictionModes.containsKey(str) ? findUxRestrictionsInList(f, this.mRestrictionModes.get(str).getRestrictionsForDriveState(i)) : null;
        if (findUxRestrictionsInList == null) {
            if (Log.isLoggable(TAG, 3)) {
                Log.d(TAG, String.format("No restrictions specified for (mode: %s, drive state: %s)", str, Integer.valueOf(i)));
            }
            findUxRestrictionsInList = findUxRestrictionsInList(f, this.mRestrictionModes.get(CarUxRestrictionsManager.UX_RESTRICTION_MODE_BASELINE).getRestrictionsForDriveState(i));
        }
        if (findUxRestrictionsInList != null) {
            return createUxRestrictionsEvent(findUxRestrictionsInList.mReqOpt, findUxRestrictionsInList.mRestrictions);
        }
        if (!Build.IS_ENG && !Build.IS_USERDEBUG) {
            return createDefaultUxRestrictionsEvent();
        }
        throw new IllegalStateException("No restrictions for driving state " + getDrivingStateName(i));
    }

    public Byte getPhysicalPort() {
        return this.mPhysicalPort;
    }

    private static RestrictionsPerSpeedRange findUxRestrictionsInList(float f, List<RestrictionsPerSpeedRange> list) {
        if (list.isEmpty()) {
            return null;
        }
        if (list.size() == 1 && list.get(0).mSpeedRange == null) {
            return list.get(0);
        }
        for (RestrictionsPerSpeedRange restrictionsPerSpeedRange : list) {
            if (restrictionsPerSpeedRange.mSpeedRange != null && restrictionsPerSpeedRange.mSpeedRange.includes(f)) {
                return restrictionsPerSpeedRange;
            }
        }
        return null;
    }

    private CarUxRestrictions createDefaultUxRestrictionsEvent() {
        return createUxRestrictionsEvent(true, 511);
    }

    private CarUxRestrictions createUxRestrictionsEvent(boolean z, int i) {
        if (i != 0) {
            z = true;
        }
        CarUxRestrictions.Builder builder = new CarUxRestrictions.Builder(z, i, SystemClock.elapsedRealtimeNanos());
        int i2 = this.mMaxStringLength;
        if (i2 != -1) {
            builder.setMaxStringLength(i2);
        }
        int i3 = this.mMaxCumulativeContentItems;
        if (i3 != -1) {
            builder.setMaxCumulativeContentItems(i3);
        }
        int i4 = this.mMaxContentDepth;
        if (i4 != -1) {
            builder.setMaxContentDepth(i4);
        }
        return builder.build();
    }

    public void writeJson(JsonWriter jsonWriter) throws IOException {
        Objects.requireNonNull(jsonWriter, "writer must not be null");
        jsonWriter.setLenient(true);
        jsonWriter.beginObject();
        if (this.mPhysicalPort == null) {
            jsonWriter.name(JSON_NAME_PHYSICAL_PORT).nullValue();
        } else {
            jsonWriter.name(JSON_NAME_PHYSICAL_PORT).value((long) this.mPhysicalPort.byteValue());
        }
        jsonWriter.name(JSON_NAME_MAX_CONTENT_DEPTH).value((long) this.mMaxContentDepth);
        jsonWriter.name(JSON_NAME_MAX_CUMULATIVE_CONTENT_ITEMS).value((long) this.mMaxCumulativeContentItems);
        jsonWriter.name(JSON_NAME_MAX_STRING_LENGTH).value((long) this.mMaxStringLength);
        for (Map.Entry<String, RestrictionModeContainer> entry : this.mRestrictionModes.entrySet()) {
            jsonWriter.name(entry.getKey());
            writeRestrictionMode(jsonWriter, entry.getValue());
        }
        jsonWriter.endObject();
    }

    private void writeRestrictionMode(JsonWriter jsonWriter, RestrictionModeContainer restrictionModeContainer) throws IOException {
        jsonWriter.beginObject();
        jsonWriter.name(JSON_NAME_PARKED_RESTRICTIONS);
        writeRestrictionsList(jsonWriter, restrictionModeContainer.getRestrictionsForDriveState(0));
        jsonWriter.name(JSON_NAME_IDLING_RESTRICTIONS);
        writeRestrictionsList(jsonWriter, restrictionModeContainer.getRestrictionsForDriveState(1));
        jsonWriter.name(JSON_NAME_MOVING_RESTRICTIONS);
        writeRestrictionsList(jsonWriter, restrictionModeContainer.getRestrictionsForDriveState(2));
        jsonWriter.name(JSON_NAME_UNKNOWN_RESTRICTIONS);
        writeRestrictionsList(jsonWriter, restrictionModeContainer.getRestrictionsForDriveState(-1));
        jsonWriter.endObject();
    }

    private void writeRestrictionsList(JsonWriter jsonWriter, List<RestrictionsPerSpeedRange> list) throws IOException {
        jsonWriter.beginArray();
        for (RestrictionsPerSpeedRange restrictionsPerSpeedRange : list) {
            writeRestrictions(jsonWriter, restrictionsPerSpeedRange);
        }
        jsonWriter.endArray();
    }

    private void writeRestrictions(JsonWriter jsonWriter, RestrictionsPerSpeedRange restrictionsPerSpeedRange) throws IOException {
        jsonWriter.beginObject();
        jsonWriter.name(JSON_NAME_REQ_OPT).value(restrictionsPerSpeedRange.mReqOpt);
        jsonWriter.name(JSON_NAME_RESTRICTIONS).value((long) restrictionsPerSpeedRange.mRestrictions);
        if (restrictionsPerSpeedRange.mSpeedRange != null) {
            jsonWriter.name(JSON_NAME_SPEED_RANGE);
            jsonWriter.beginObject();
            jsonWriter.name(JSON_NAME_MIN_SPEED).value((double) restrictionsPerSpeedRange.mSpeedRange.mMinSpeed);
            jsonWriter.name(JSON_NAME_MAX_SPEED).value((double) restrictionsPerSpeedRange.mSpeedRange.mMaxSpeed);
            jsonWriter.endObject();
        }
        jsonWriter.endObject();
    }

    public String toString() {
        CharArrayWriter charArrayWriter = new CharArrayWriter();
        JsonWriter jsonWriter = new JsonWriter(charArrayWriter);
        jsonWriter.setIndent("\t");
        try {
            writeJson(jsonWriter);
        } catch (IOException e) {
            e.printStackTrace();
        }
        return charArrayWriter.toString();
    }

    public static CarUxRestrictionsConfiguration readJson(JsonReader jsonReader, int i) throws IOException {
        Objects.requireNonNull(jsonReader, "reader must not be null");
        jsonReader.setLenient(true);
        RestrictionConfigurationParser createConfigurationParser = createConfigurationParser(i);
        Builder builder = new Builder();
        jsonReader.beginObject();
        while (jsonReader.hasNext()) {
            String nextName = jsonReader.nextName();
            nextName.hashCode();
            char c = 65535;
            switch (nextName.hashCode()) {
                case -1631290199:
                    if (nextName.equals(JSON_NAME_MAX_CUMULATIVE_CONTENT_ITEMS)) {
                        c = 0;
                        break;
                    }
                    break;
                case -1059087390:
                    if (nextName.equals(JSON_NAME_MAX_CONTENT_DEPTH)) {
                        c = 1;
                        break;
                    }
                    break;
                case -1030681799:
                    if (nextName.equals(JSON_NAME_MAX_STRING_LENGTH)) {
                        c = 2;
                        break;
                    }
                    break;
                case 1538350825:
                    if (nextName.equals(JSON_NAME_PHYSICAL_PORT)) {
                        c = 3;
                        break;
                    }
                    break;
            }
            switch (c) {
                case 0:
                    builder.setMaxCumulativeContentItems(jsonReader.nextInt());
                    break;
                case 1:
                    builder.setMaxContentDepth(jsonReader.nextInt());
                    break;
                case 2:
                    builder.setMaxStringLength(jsonReader.nextInt());
                    break;
                case 3:
                    if (jsonReader.peek() != JsonToken.NULL) {
                        builder.setPhysicalPort(Builder.validatePort(jsonReader.nextInt()));
                        break;
                    } else {
                        jsonReader.nextNull();
                        break;
                    }
                default:
                    createConfigurationParser.readJson(jsonReader, nextName, builder);
                    break;
            }
        }
        jsonReader.endObject();
        return builder.build();
    }

    private static RestrictionConfigurationParser createConfigurationParser(int i) {
        if (i == 1) {
            return new V1RestrictionConfigurationParser();
        }
        if (i == 2) {
            return new V2RestrictionConfigurationParser();
        }
        throw new IllegalArgumentException("No parser supported for schemaVersion " + i);
    }

    /* access modifiers changed from: private */
    public static class V2RestrictionConfigurationParser implements RestrictionConfigurationParser {
        private V2RestrictionConfigurationParser() {
        }

        @Override // android.car.drivingstate.CarUxRestrictionsConfiguration.RestrictionConfigurationParser
        public void readJson(JsonReader jsonReader, String str, Builder builder) throws IOException {
            CarUxRestrictionsConfiguration.readRestrictionsMode(jsonReader, str, builder);
        }
    }

    /* access modifiers changed from: private */
    public static class V1RestrictionConfigurationParser implements RestrictionConfigurationParser {
        private static final String JSON_NAME_PASSENGER_IDLING_RESTRICTIONS = "passenger_idling_restrictions";
        private static final String JSON_NAME_PASSENGER_MOVING_RESTRICTIONS = "passenger_moving_restrictions";
        private static final String JSON_NAME_PASSENGER_PARKED_RESTRICTIONS = "passenger_parked_restrictions";
        private static final String JSON_NAME_PASSENGER_UNKNOWN_RESTRICTIONS = "passenger_unknown_restrictions";
        private static final String PASSENGER_MODE_NAME_FOR_MIGRATION = "passenger";

        private V1RestrictionConfigurationParser() {
        }

        /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
        @Override // android.car.drivingstate.CarUxRestrictionsConfiguration.RestrictionConfigurationParser
        public void readJson(JsonReader jsonReader, String str, Builder builder) throws IOException {
            char c;
            str.hashCode();
            switch (str.hashCode()) {
                case -1828817279:
                    if (str.equals(JSON_NAME_PASSENGER_UNKNOWN_RESTRICTIONS)) {
                        c = 0;
                        break;
                    }
                    c = 65535;
                    break;
                case -1781561187:
                    if (str.equals(CarUxRestrictionsConfiguration.JSON_NAME_PARKED_RESTRICTIONS)) {
                        c = 1;
                        break;
                    }
                    c = 65535;
                    break;
                case -321131524:
                    if (str.equals(CarUxRestrictionsConfiguration.JSON_NAME_UNKNOWN_RESTRICTIONS)) {
                        c = 2;
                        break;
                    }
                    c = 65535;
                    break;
                case 242100051:
                    if (str.equals(JSON_NAME_PASSENGER_MOVING_RESTRICTIONS)) {
                        c = 3;
                        break;
                    }
                    c = 65535;
                    break;
                case 983471736:
                    if (str.equals(CarUxRestrictionsConfiguration.JSON_NAME_MOVING_RESTRICTIONS)) {
                        c = 4;
                        break;
                    }
                    c = 65535;
                    break;
                case 1054686448:
                    if (str.equals(JSON_NAME_PASSENGER_IDLING_RESTRICTIONS)) {
                        c = 5;
                        break;
                    }
                    c = 65535;
                    break;
                case 1772034424:
                    if (str.equals(JSON_NAME_PASSENGER_PARKED_RESTRICTIONS)) {
                        c = 6;
                        break;
                    }
                    c = 65535;
                    break;
                case 1796058133:
                    if (str.equals(CarUxRestrictionsConfiguration.JSON_NAME_IDLING_RESTRICTIONS)) {
                        c = 7;
                        break;
                    }
                    c = 65535;
                    break;
                default:
                    c = 65535;
                    break;
            }
            switch (c) {
                case 0:
                    CarUxRestrictionsConfiguration.readRestrictionsList(jsonReader, -1, PASSENGER_MODE_NAME_FOR_MIGRATION, builder);
                    return;
                case 1:
                    CarUxRestrictionsConfiguration.readRestrictionsList(jsonReader, 0, CarUxRestrictionsManager.UX_RESTRICTION_MODE_BASELINE, builder);
                    return;
                case 2:
                    CarUxRestrictionsConfiguration.readRestrictionsList(jsonReader, -1, CarUxRestrictionsManager.UX_RESTRICTION_MODE_BASELINE, builder);
                    return;
                case 3:
                    CarUxRestrictionsConfiguration.readRestrictionsList(jsonReader, 2, PASSENGER_MODE_NAME_FOR_MIGRATION, builder);
                    return;
                case 4:
                    CarUxRestrictionsConfiguration.readRestrictionsList(jsonReader, 2, CarUxRestrictionsManager.UX_RESTRICTION_MODE_BASELINE, builder);
                    return;
                case 5:
                    CarUxRestrictionsConfiguration.readRestrictionsList(jsonReader, 1, PASSENGER_MODE_NAME_FOR_MIGRATION, builder);
                    return;
                case 6:
                    CarUxRestrictionsConfiguration.readRestrictionsList(jsonReader, 0, PASSENGER_MODE_NAME_FOR_MIGRATION, builder);
                    return;
                case 7:
                    CarUxRestrictionsConfiguration.readRestrictionsList(jsonReader, 1, CarUxRestrictionsManager.UX_RESTRICTION_MODE_BASELINE, builder);
                    return;
                default:
                    Log.e(CarUxRestrictionsConfiguration.TAG, "Unknown name parsing json config: " + str);
                    jsonReader.skipValue();
                    return;
            }
        }
    }

    /* access modifiers changed from: private */
    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    public static void readRestrictionsMode(JsonReader jsonReader, String str, Builder builder) throws IOException {
        char c;
        jsonReader.beginObject();
        while (jsonReader.hasNext()) {
            String nextName = jsonReader.nextName();
            nextName.hashCode();
            switch (nextName.hashCode()) {
                case -1781561187:
                    if (nextName.equals(JSON_NAME_PARKED_RESTRICTIONS)) {
                        c = 0;
                        break;
                    }
                    c = 65535;
                    break;
                case -321131524:
                    if (nextName.equals(JSON_NAME_UNKNOWN_RESTRICTIONS)) {
                        c = 1;
                        break;
                    }
                    c = 65535;
                    break;
                case 983471736:
                    if (nextName.equals(JSON_NAME_MOVING_RESTRICTIONS)) {
                        c = 2;
                        break;
                    }
                    c = 65535;
                    break;
                case 1796058133:
                    if (nextName.equals(JSON_NAME_IDLING_RESTRICTIONS)) {
                        c = 3;
                        break;
                    }
                    c = 65535;
                    break;
                default:
                    c = 65535;
                    break;
            }
            switch (c) {
                case 0:
                    readRestrictionsList(jsonReader, 0, str, builder);
                    break;
                case 1:
                    readRestrictionsList(jsonReader, -1, str, builder);
                    break;
                case 2:
                    readRestrictionsList(jsonReader, 2, str, builder);
                    break;
                case 3:
                    readRestrictionsList(jsonReader, 1, str, builder);
                    break;
                default:
                    Log.e(TAG, "Unknown name parsing restriction mode json config: " + nextName);
                    break;
            }
        }
        jsonReader.endObject();
    }

    /* access modifiers changed from: private */
    public static void readRestrictionsList(JsonReader jsonReader, int i, String str, Builder builder) throws IOException {
        jsonReader.beginArray();
        while (jsonReader.hasNext()) {
            DrivingStateRestrictions readRestrictions = readRestrictions(jsonReader);
            readRestrictions.setMode(str);
            builder.setUxRestrictions(i, readRestrictions);
        }
        jsonReader.endArray();
    }

    private static DrivingStateRestrictions readRestrictions(JsonReader jsonReader) throws IOException {
        jsonReader.beginObject();
        boolean z = false;
        Builder.SpeedRange speedRange = null;
        int i = 0;
        while (jsonReader.hasNext()) {
            String nextName = jsonReader.nextName();
            if (nextName.equals(JSON_NAME_REQ_OPT)) {
                z = jsonReader.nextBoolean();
            } else if (nextName.equals(JSON_NAME_RESTRICTIONS)) {
                i = jsonReader.nextInt();
            } else if (nextName.equals(JSON_NAME_SPEED_RANGE)) {
                jsonReader.beginObject();
                float f = Float.POSITIVE_INFINITY;
                float f2 = Float.POSITIVE_INFINITY;
                while (jsonReader.hasNext()) {
                    String nextName2 = jsonReader.nextName();
                    if (nextName2.equals(JSON_NAME_MIN_SPEED)) {
                        f = Double.valueOf(jsonReader.nextDouble()).floatValue();
                    } else if (nextName2.equals(JSON_NAME_MAX_SPEED)) {
                        f2 = Double.valueOf(jsonReader.nextDouble()).floatValue();
                    } else {
                        Log.e(TAG, "Unknown name parsing json config: " + nextName2);
                        jsonReader.skipValue();
                    }
                }
                Builder.SpeedRange speedRange2 = new Builder.SpeedRange(f, f2);
                jsonReader.endObject();
                speedRange = speedRange2;
            }
        }
        jsonReader.endObject();
        DrivingStateRestrictions restrictions = new DrivingStateRestrictions().setDistractionOptimizationRequired(z).setRestrictions(i);
        if (speedRange != null) {
            restrictions.setSpeedRange(speedRange);
        }
        return restrictions;
    }

    public int hashCode() {
        return Objects.hash(this.mPhysicalPort, Integer.valueOf(this.mMaxStringLength), Integer.valueOf(this.mMaxCumulativeContentItems), Integer.valueOf(this.mMaxContentDepth), this.mRestrictionModes);
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof CarUxRestrictionsConfiguration)) {
            return false;
        }
        CarUxRestrictionsConfiguration carUxRestrictionsConfiguration = (CarUxRestrictionsConfiguration) obj;
        return this.mPhysicalPort == carUxRestrictionsConfiguration.mPhysicalPort && hasSameParameters(carUxRestrictionsConfiguration) && this.mRestrictionModes.equals(carUxRestrictionsConfiguration.mRestrictionModes);
    }

    public boolean hasSameParameters(CarUxRestrictionsConfiguration carUxRestrictionsConfiguration) {
        Objects.requireNonNull(carUxRestrictionsConfiguration, "other must not be null");
        return this.mMaxContentDepth == carUxRestrictionsConfiguration.mMaxContentDepth && this.mMaxCumulativeContentItems == carUxRestrictionsConfiguration.mMaxCumulativeContentItems && this.mMaxStringLength == carUxRestrictionsConfiguration.mMaxStringLength;
    }

    public void dump(PrintWriter printWriter) {
        Objects.requireNonNull(printWriter, "writer must not be null");
        printWriter.println("Physical display port: " + this.mPhysicalPort);
        for (Map.Entry<String, RestrictionModeContainer> entry : this.mRestrictionModes.entrySet()) {
            printWriter.println("===========================================");
            printWriter.println(entry.getKey() + " mode UXR:");
            printWriter.println("-------------------------------------------");
            dumpRestrictions(printWriter, entry.getValue().mDriveStateUxRestrictions);
        }
        printWriter.println("Max String length: " + this.mMaxStringLength);
        printWriter.println("Max Cumulative Content Items: " + this.mMaxCumulativeContentItems);
        printWriter.println("Max Content depth: " + this.mMaxContentDepth);
        printWriter.println("===========================================");
    }

    private void dumpRestrictions(PrintWriter printWriter, Map<Integer, List<RestrictionsPerSpeedRange>> map) {
        for (Integer num : map.keySet()) {
            List<RestrictionsPerSpeedRange> list = map.get(num);
            printWriter.println("State:" + getDrivingStateName(num.intValue()) + " num restrictions:" + list.size());
            for (RestrictionsPerSpeedRange restrictionsPerSpeedRange : list) {
                printWriter.println(new StringBuilder().append("Requires DO? ").append(restrictionsPerSpeedRange.mReqOpt).append("\nRestrictions: 0x").append(Integer.toHexString(restrictionsPerSpeedRange.mRestrictions)).append("\nSpeed Range: ").append(restrictionsPerSpeedRange.mSpeedRange == null ? "None" : restrictionsPerSpeedRange.mSpeedRange.mMinSpeed + " - " + restrictionsPerSpeedRange.mSpeedRange.mMaxSpeed).toString());
                printWriter.println("-------------------------------------------");
            }
        }
    }

    /* access modifiers changed from: private */
    public static String getDrivingStateName(int i) {
        if (i == -1) {
            return "unknown";
        }
        if (i == 0) {
            return "parked";
        }
        if (i == 1) {
            return "idling";
        }
        if (i == 2) {
            return "moving";
        }
        throw new IllegalArgumentException("Unrecognized state value: " + i);
    }

    private CarUxRestrictionsConfiguration(Parcel parcel) {
        Byte b;
        this.mRestrictionModes = new ArrayMap();
        int readInt = parcel.readInt();
        for (int i = 0; i < readInt; i++) {
            String readString = parcel.readString();
            RestrictionModeContainer restrictionModeContainer = new RestrictionModeContainer();
            int[] iArr = DRIVING_STATES;
            for (int i2 : iArr) {
                ArrayList arrayList = new ArrayList();
                parcel.readTypedList(arrayList, RestrictionsPerSpeedRange.CREATOR);
                restrictionModeContainer.setRestrictionsForDriveState(i2, arrayList);
            }
            this.mRestrictionModes.put(readString, restrictionModeContainer);
        }
        boolean readBoolean = parcel.readBoolean();
        byte readByte = parcel.readByte();
        if (readBoolean) {
            b = null;
        } else {
            b = Byte.valueOf(readByte);
        }
        this.mPhysicalPort = b;
        this.mMaxContentDepth = parcel.readInt();
        this.mMaxCumulativeContentItems = parcel.readInt();
        this.mMaxStringLength = parcel.readInt();
    }

    public void writeToParcel(Parcel parcel, int i) {
        byte b;
        parcel.writeInt(this.mRestrictionModes.size());
        Iterator<Map.Entry<String, RestrictionModeContainer>> it = this.mRestrictionModes.entrySet().iterator();
        while (true) {
            b = 0;
            if (!it.hasNext()) {
                break;
            }
            Map.Entry<String, RestrictionModeContainer> next = it.next();
            parcel.writeString(next.getKey());
            for (int i2 : DRIVING_STATES) {
                parcel.writeTypedList(next.getValue().getRestrictionsForDriveState(i2));
            }
        }
        boolean z = this.mPhysicalPort == null;
        parcel.writeBoolean(z);
        if (!z) {
            b = this.mPhysicalPort.byteValue();
        }
        parcel.writeByte(b);
        parcel.writeInt(this.mMaxContentDepth);
        parcel.writeInt(this.mMaxCumulativeContentItems);
        parcel.writeInt(this.mMaxStringLength);
    }

    public static final class Builder {
        private static final int UX_RESTRICTIONS_UNKNOWN = -1;
        private int mMaxContentDepth = -1;
        private int mMaxCumulativeContentItems = -1;
        private int mMaxStringLength = -1;
        private Byte mPhysicalPort;
        public final Map<String, RestrictionModeContainer> mRestrictionModes;

        public static byte validatePort(int i) {
            if (-128 <= i && i <= 127) {
                return (byte) i;
            }
            throw new IllegalArgumentException("Port value should be within the range of a byte. Input is " + i);
        }

        public Builder() {
            ArrayMap arrayMap = new ArrayMap();
            this.mRestrictionModes = arrayMap;
            arrayMap.put(CarUxRestrictionsManager.UX_RESTRICTION_MODE_BASELINE, new RestrictionModeContainer());
        }

        public Builder setPhysicalPort(byte b) {
            this.mPhysicalPort = Byte.valueOf(b);
            return this;
        }

        public Builder setUxRestrictions(int i, boolean z, int i2) {
            return setUxRestrictions(i, new DrivingStateRestrictions().setDistractionOptimizationRequired(z).setRestrictions(i2));
        }

        @Deprecated
        public Builder setUxRestrictions(int i, SpeedRange speedRange, boolean z, int i2) {
            return setUxRestrictions(i, new DrivingStateRestrictions().setDistractionOptimizationRequired(z).setRestrictions(i2).setSpeedRange(speedRange));
        }

        public Builder setUxRestrictions(int i, DrivingStateRestrictions drivingStateRestrictions) {
            SpeedRange speedRange = drivingStateRestrictions.mSpeedRange;
            if (i == 2 || speedRange == null) {
                this.mRestrictionModes.computeIfAbsent(drivingStateRestrictions.mMode, $$Lambda$CarUxRestrictionsConfiguration$Builder$_HwMxjJ88yII8kDzYrvGlzd4Yo.INSTANCE).getRestrictionsForDriveState(i).add(new RestrictionsPerSpeedRange(drivingStateRestrictions.mMode, drivingStateRestrictions.mReqOpt, drivingStateRestrictions.mRestrictions, speedRange));
                return this;
            }
            throw new IllegalArgumentException("Non-moving driving state should not specify speed range.");
        }

        static /* synthetic */ RestrictionModeContainer lambda$setUxRestrictions$0(String str) {
            return new RestrictionModeContainer();
        }

        public Builder setMaxStringLength(int i) {
            this.mMaxStringLength = i;
            return this;
        }

        public Builder setMaxCumulativeContentItems(int i) {
            this.mMaxCumulativeContentItems = i;
            return this;
        }

        public Builder setMaxContentDepth(int i) {
            this.mMaxContentDepth = i;
            return this;
        }

        public CarUxRestrictionsConfiguration build() {
            addDefaultRestrictionsToBaseline();
            validateBaselineModeRestrictions();
            for (String str : this.mRestrictionModes.keySet()) {
                if (!CarUxRestrictionsManager.UX_RESTRICTION_MODE_BASELINE.equals(str)) {
                    validateModeRestrictions(str);
                }
            }
            return new CarUxRestrictionsConfiguration(this);
        }

        private void addDefaultRestrictionsToBaseline() {
            RestrictionModeContainer restrictionModeContainer = this.mRestrictionModes.get(CarUxRestrictionsManager.UX_RESTRICTION_MODE_BASELINE);
            int[] iArr = CarUxRestrictionsConfiguration.DRIVING_STATES;
            for (int i : iArr) {
                List<RestrictionsPerSpeedRange> restrictionsForDriveState = restrictionModeContainer.getRestrictionsForDriveState(i);
                if (restrictionsForDriveState.size() == 0) {
                    Log.i(CarUxRestrictionsConfiguration.TAG, "Using default restrictions for driving state: " + CarUxRestrictionsConfiguration.getDrivingStateName(i));
                    restrictionsForDriveState.add(new RestrictionsPerSpeedRange(true, 511));
                }
            }
        }

        private void validateBaselineModeRestrictions() {
            RestrictionModeContainer restrictionModeContainer = this.mRestrictionModes.get(CarUxRestrictionsManager.UX_RESTRICTION_MODE_BASELINE);
            int[] iArr = CarUxRestrictionsConfiguration.DRIVING_STATES;
            for (int i : iArr) {
                List<RestrictionsPerSpeedRange> restrictionsForDriveState = restrictionModeContainer.getRestrictionsForDriveState(i);
                if (i != 2 && restrictionsForDriveState.size() != 1) {
                    throw new IllegalStateException("Non-moving driving state should contain one set of restriction rules.");
                } else if (restrictionsForDriveState.size() <= 1 || !restrictionsForDriveState.stream().anyMatch($$Lambda$CarUxRestrictionsConfiguration$Builder$mpXtv39MROh7dAz94lQpTyXDMVY.INSTANCE)) {
                    Collections.sort(restrictionsForDriveState, Comparator.comparing($$Lambda$QhPuT58P0RywXmOCKDnl5Xjz3DA.INSTANCE));
                    validateRangeOfSpeed(restrictionsForDriveState);
                    validateContinuousSpeedRange(restrictionsForDriveState);
                } else {
                    StringBuilder sb = new StringBuilder();
                    for (RestrictionsPerSpeedRange restrictionsPerSpeedRange : restrictionsForDriveState) {
                        sb.append(restrictionsPerSpeedRange.toString()).append('\n');
                    }
                    throw new IllegalStateException("Every restriction in MOVING state should contain driving state.\n" + sb.toString());
                }
            }
        }

        static /* synthetic */ boolean lambda$validateBaselineModeRestrictions$1(RestrictionsPerSpeedRange restrictionsPerSpeedRange) {
            return restrictionsPerSpeedRange.mSpeedRange == null;
        }

        private void validateModeRestrictions(String str) {
            if (this.mRestrictionModes.containsKey(str)) {
                List<RestrictionsPerSpeedRange> restrictionsForDriveState = this.mRestrictionModes.get(str).getRestrictionsForDriveState(2);
                Collections.sort(restrictionsForDriveState, Comparator.comparing($$Lambda$QhPuT58P0RywXmOCKDnl5Xjz3DA.INSTANCE));
                validateContinuousSpeedRange(restrictionsForDriveState);
            }
        }

        private void validateRangeOfSpeed(List<RestrictionsPerSpeedRange> list) {
            if (list.size() != 1 || list.get(0).mSpeedRange != null) {
                if (Float.compare(list.get(0).mSpeedRange.mMinSpeed, 0.0f) != 0) {
                    throw new IllegalStateException("Speed range min speed should start at 0.");
                } else if (Float.compare(list.get(list.size() - 1).mSpeedRange.mMaxSpeed, Float.POSITIVE_INFINITY) != 0) {
                    throw new IllegalStateException("Max speed of last restriction should be MAX_SPEED.");
                }
            }
        }

        private void validateContinuousSpeedRange(List<RestrictionsPerSpeedRange> list) {
            for (int i = 1; i < list.size(); i++) {
                if (Float.compare(list.get(i).mSpeedRange.mMinSpeed, list.get(i - 1).mSpeedRange.mMaxSpeed) != 0) {
                    throw new IllegalArgumentException("Mis-configured speed range. Possibly speed range overlap or gap.");
                }
            }
        }

        public static final class SpeedRange implements Comparable<SpeedRange> {
            public static final float MAX_SPEED = Float.POSITIVE_INFINITY;
            private float mMaxSpeed;
            private float mMinSpeed;

            public SpeedRange(float f) {
                this(f, Float.POSITIVE_INFINITY);
            }

            public SpeedRange(float f, float f2) {
                if (Float.compare(f, 0.0f) < 0 || Float.compare(f2, 0.0f) < 0) {
                    throw new IllegalArgumentException("Speed cannot be negative.");
                } else if (f == Float.POSITIVE_INFINITY) {
                    throw new IllegalArgumentException("Min speed cannot be MAX_SPEED.");
                } else if (f <= f2) {
                    this.mMinSpeed = f;
                    this.mMaxSpeed = f2;
                } else {
                    throw new IllegalArgumentException("Min speed " + f + " should not be greater than max speed " + f2);
                }
            }

            public boolean includes(float f) {
                return this.mMinSpeed <= f && f < this.mMaxSpeed;
            }

            public int compareTo(SpeedRange speedRange) {
                int compare = Float.compare(this.mMinSpeed, speedRange.mMinSpeed);
                if (compare != 0) {
                    return compare;
                }
                return Float.compare(this.mMaxSpeed, speedRange.mMaxSpeed);
            }

            public int hashCode() {
                return Objects.hash(Float.valueOf(this.mMinSpeed), Float.valueOf(this.mMaxSpeed));
            }

            public boolean equals(Object obj) {
                if (this == obj) {
                    return true;
                }
                if (!(obj instanceof SpeedRange)) {
                    return false;
                }
                return compareTo((SpeedRange) obj) == 0;
            }

            public String toString() {
                StringBuilder append = new StringBuilder().append("[min: ").append(this.mMinSpeed).append("; max: ");
                float f = this.mMaxSpeed;
                return append.append(f == Float.POSITIVE_INFINITY ? CarUxRestrictionsConfiguration.JSON_NAME_MAX_SPEED : Float.valueOf(f)).append("]").toString();
            }
        }
    }

    public static final class DrivingStateRestrictions {
        private String mMode = CarUxRestrictionsManager.UX_RESTRICTION_MODE_BASELINE;
        private boolean mReqOpt = true;
        private int mRestrictions = 511;
        private Builder.SpeedRange mSpeedRange;

        public DrivingStateRestrictions setDistractionOptimizationRequired(boolean z) {
            this.mReqOpt = z;
            return this;
        }

        public DrivingStateRestrictions setRestrictions(int i) {
            this.mRestrictions = i;
            return this;
        }

        public DrivingStateRestrictions setMode(String str) {
            this.mMode = (String) Objects.requireNonNull(str, "mode must not be null");
            return this;
        }

        public DrivingStateRestrictions setSpeedRange(Builder.SpeedRange speedRange) {
            this.mSpeedRange = speedRange;
            return this;
        }

        public String toString() {
            StringBuilder append = new StringBuilder().append("Mode: ").append(this.mMode).append(". Requires DO? ").append(this.mReqOpt).append(". Restrictions: ").append(Integer.toBinaryString(this.mRestrictions)).append(". SpeedRange: ");
            Builder.SpeedRange speedRange = this.mSpeedRange;
            return append.append(speedRange == null ? "null" : speedRange.toString()).toString();
        }
    }

    /* access modifiers changed from: private */
    public static final class RestrictionsPerSpeedRange implements Parcelable {
        public static final Parcelable.Creator<RestrictionsPerSpeedRange> CREATOR = new Parcelable.Creator<RestrictionsPerSpeedRange>() {
            /* class android.car.drivingstate.CarUxRestrictionsConfiguration.RestrictionsPerSpeedRange.AnonymousClass1 */

            @Override // android.os.Parcelable.Creator
            public RestrictionsPerSpeedRange createFromParcel(Parcel parcel) {
                return new RestrictionsPerSpeedRange(parcel);
            }

            @Override // android.os.Parcelable.Creator
            public RestrictionsPerSpeedRange[] newArray(int i) {
                return new RestrictionsPerSpeedRange[i];
            }
        };
        final String mMode;
        final boolean mReqOpt;
        final int mRestrictions;
        final Builder.SpeedRange mSpeedRange;

        public int describeContents() {
            return 0;
        }

        RestrictionsPerSpeedRange(boolean z, int i) {
            this(CarUxRestrictionsManager.UX_RESTRICTION_MODE_BASELINE, z, i, null);
        }

        RestrictionsPerSpeedRange(String str, boolean z, int i, Builder.SpeedRange speedRange) {
            if (z || i == 0) {
                this.mMode = (String) Objects.requireNonNull(str, "mode must not be null");
                this.mReqOpt = z;
                this.mRestrictions = i;
                this.mSpeedRange = speedRange;
                return;
            }
            throw new IllegalArgumentException("Driving optimization is not required but UX restrictions is required.");
        }

        public Builder.SpeedRange getSpeedRange() {
            return this.mSpeedRange;
        }

        public int hashCode() {
            return Objects.hash(this.mMode, Boolean.valueOf(this.mReqOpt), Integer.valueOf(this.mRestrictions), this.mSpeedRange);
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null || !(obj instanceof RestrictionsPerSpeedRange)) {
                return false;
            }
            RestrictionsPerSpeedRange restrictionsPerSpeedRange = (RestrictionsPerSpeedRange) obj;
            return Objects.equals(this.mMode, restrictionsPerSpeedRange.mMode) && this.mReqOpt == restrictionsPerSpeedRange.mReqOpt && this.mRestrictions == restrictionsPerSpeedRange.mRestrictions && Objects.equals(this.mSpeedRange, restrictionsPerSpeedRange.mSpeedRange);
        }

        public String toString() {
            StringBuilder append = new StringBuilder().append("[Mode is ").append(this.mMode).append("; Requires DO? ").append(this.mReqOpt).append("; Restrictions: ").append(Integer.toBinaryString(this.mRestrictions)).append("; Speed range: ");
            Builder.SpeedRange speedRange = this.mSpeedRange;
            return append.append(speedRange == null ? "null" : speedRange.toString()).append(']').toString();
        }

        protected RestrictionsPerSpeedRange(Parcel parcel) {
            this.mMode = parcel.readString();
            this.mReqOpt = parcel.readBoolean();
            this.mRestrictions = parcel.readInt();
            this.mSpeedRange = parcel.readBoolean() ? new Builder.SpeedRange(parcel.readFloat(), parcel.readFloat()) : null;
        }

        public void writeToParcel(Parcel parcel, int i) {
            parcel.writeString(this.mMode);
            parcel.writeBoolean(this.mReqOpt);
            parcel.writeInt(this.mRestrictions);
            parcel.writeBoolean(this.mSpeedRange != null);
            Builder.SpeedRange speedRange = this.mSpeedRange;
            if (speedRange != null) {
                parcel.writeFloat(speedRange.mMinSpeed);
                parcel.writeFloat(this.mSpeedRange.mMaxSpeed);
            }
        }
    }

    /* access modifiers changed from: private */
    public static final class RestrictionModeContainer {
        private final Map<Integer, List<RestrictionsPerSpeedRange>> mDriveStateUxRestrictions = new ArrayMap(CarUxRestrictionsConfiguration.DRIVING_STATES.length);

        RestrictionModeContainer() {
            for (int i : CarUxRestrictionsConfiguration.DRIVING_STATES) {
                this.mDriveStateUxRestrictions.put(Integer.valueOf(i), new ArrayList());
            }
        }

        /* access modifiers changed from: package-private */
        public List<RestrictionsPerSpeedRange> getRestrictionsForDriveState(int i) {
            return this.mDriveStateUxRestrictions.get(Integer.valueOf(i));
        }

        /* access modifiers changed from: package-private */
        public void setRestrictionsForDriveState(int i, List<RestrictionsPerSpeedRange> list) {
            Objects.requireNonNull(list, "null restrictions are not allows");
            this.mDriveStateUxRestrictions.put(Integer.valueOf(i), list);
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof RestrictionModeContainer)) {
                return false;
            }
            return Objects.equals(this.mDriveStateUxRestrictions, ((RestrictionModeContainer) obj).mDriveStateUxRestrictions);
        }

        public int hashCode() {
            return Objects.hash(this.mDriveStateUxRestrictions);
        }
    }
}
