package android.car.hardware.power;

import android.annotation.SystemApi;
import android.car.Car;
import android.car.CarManagerBase;
import android.car.hardware.power.ICarPower;
import android.car.hardware.power.ICarPowerStateListener;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import java.util.concurrent.CancellationException;
import java.util.concurrent.CompletableFuture;
import java.util.function.BiConsumer;

@SystemApi
public class CarPowerManager extends CarManagerBase {
    private static final boolean DBG = false;
    private static final String TAG = "CarPowerManager";
    private CompletableFuture<Void> mFuture;
    private CarPowerStateListener mListener;
    private ICarPowerStateListener mListenerToService;
    private CarPowerStateListenerWithCompletion mListenerWithCompletion;
    private final Object mLock = new Object();
    private final ICarPower mService;

    public interface CarPowerStateListener {
        public static final int INVALID = 0;
        public static final int ON = 6;
        public static final int SHUTDOWN_CANCELLED = 8;
        public static final int SHUTDOWN_ENTER = 5;
        public static final int SHUTDOWN_PREPARE = 7;
        public static final int SUSPEND_ENTER = 2;
        public static final int SUSPEND_EXIT = 3;
        public static final int WAIT_FOR_VHAL = 1;

        void onStateChanged(int i);
    }

    public interface CarPowerStateListenerWithCompletion {
        void onStateChanged(int i, CompletableFuture<Void> completableFuture);
    }

    public CarPowerManager(Car car, IBinder iBinder) {
        super(car);
        this.mService = ICarPower.Stub.asInterface(iBinder);
    }

    public void requestShutdownOnNextSuspend() {
        try {
            this.mService.requestShutdownOnNextSuspend();
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    public void scheduleNextWakeupTime(int i) {
        try {
            this.mService.scheduleNextWakeupTime(i);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    public int getPowerState() {
        try {
            return this.mService.getPowerState();
        } catch (RemoteException e) {
            return ((Integer) handleRemoteExceptionFromCarService(e, 0)).intValue();
        }
    }

    public void setListener(CarPowerStateListener carPowerStateListener) {
        synchronized (this.mLock) {
            if (this.mListener == null && this.mListenerWithCompletion == null) {
                this.mListener = carPowerStateListener;
                setServiceForListenerLocked(false);
            } else {
                throw new IllegalStateException("Listener must be cleared first");
            }
        }
    }

    public void setListenerWithCompletion(CarPowerStateListenerWithCompletion carPowerStateListenerWithCompletion) {
        synchronized (this.mLock) {
            if (this.mListener == null && this.mListenerWithCompletion == null) {
                this.mListenerWithCompletion = carPowerStateListenerWithCompletion;
                setServiceForListenerLocked(true);
            } else {
                throw new IllegalStateException("Listener must be cleared first");
            }
        }
    }

    private void setServiceForListenerLocked(final boolean z) {
        if (this.mListenerToService == null) {
            AnonymousClass1 r0 = new ICarPowerStateListener.Stub() {
                /* class android.car.hardware.power.CarPowerManager.AnonymousClass1 */

                @Override // android.car.hardware.power.ICarPowerStateListener
                public void onStateChanged(int i) throws RemoteException {
                    CarPowerStateListener carPowerStateListener;
                    CarPowerStateListenerWithCompletion carPowerStateListenerWithCompletion;
                    CompletableFuture<Void> completableFuture;
                    if (z) {
                        synchronized (CarPowerManager.this.mLock) {
                            CarPowerManager.this.updateFutureLocked(i);
                            carPowerStateListenerWithCompletion = CarPowerManager.this.mListenerWithCompletion;
                            completableFuture = CarPowerManager.this.mFuture;
                        }
                        if (carPowerStateListenerWithCompletion != null) {
                            carPowerStateListenerWithCompletion.onStateChanged(i, completableFuture);
                            return;
                        }
                        return;
                    }
                    synchronized (CarPowerManager.this.mLock) {
                        carPowerStateListener = CarPowerManager.this.mListener;
                    }
                    if (carPowerStateListener != null) {
                        carPowerStateListener.onStateChanged(i);
                    }
                }
            };
            if (z) {
                try {
                    this.mService.registerListenerWithCompletion(r0);
                } catch (RemoteException e) {
                    handleRemoteExceptionFromCarService(e);
                    return;
                }
            } else {
                this.mService.registerListener(r0);
            }
            this.mListenerToService = r0;
        }
    }

    public void clearListener() {
        ICarPowerStateListener iCarPowerStateListener;
        synchronized (this.mLock) {
            iCarPowerStateListener = this.mListenerToService;
            this.mListenerToService = null;
            this.mListener = null;
            this.mListenerWithCompletion = null;
            cleanupFutureLocked();
        }
        if (iCarPowerStateListener == null) {
            Log.w(TAG, "unregisterListener: listener was not registered");
            return;
        }
        try {
            this.mService.unregisterListener(iCarPowerStateListener);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateFutureLocked(int i) {
        cleanupFutureLocked();
        if (i == 7) {
            CompletableFuture<Void> completableFuture = new CompletableFuture<>();
            this.mFuture = completableFuture;
            completableFuture.whenComplete((BiConsumer<? super Void, ? super Throwable>) new BiConsumer() {
                /* class android.car.hardware.power.$$Lambda$CarPowerManager$MRapa2PEiAi77wzcvKFzSUySzMc */

                @Override // java.util.function.BiConsumer
                public final void accept(Object obj, Object obj2) {
                    CarPowerManager.this.lambda$updateFutureLocked$0$CarPowerManager((Void) obj, (Throwable) obj2);
                }
            });
        }
    }

    public /* synthetic */ void lambda$updateFutureLocked$0$CarPowerManager(Void r2, Throwable th) {
        ICarPowerStateListener iCarPowerStateListener;
        if (th != null && !(th instanceof CancellationException)) {
            Log.e(TAG, "Exception occurred while waiting for future", th);
        }
        synchronized (this.mLock) {
            iCarPowerStateListener = this.mListenerToService;
        }
        try {
            this.mService.finished(iCarPowerStateListener);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    private void cleanupFutureLocked() {
        CompletableFuture<Void> completableFuture = this.mFuture;
        if (completableFuture != null) {
            if (!completableFuture.isDone()) {
                this.mFuture.cancel(false);
            }
            this.mFuture = null;
        }
    }

    @Override // android.car.CarManagerBase
    public void onCarDisconnected() {
        synchronized (this.mLock) {
            this.mListener = null;
            this.mListenerWithCompletion = null;
        }
    }
}
