package android.car.input;

import android.car.Car;
import android.car.CarManagerBase;
import android.car.input.ICarInput;
import android.car.input.ICarInputCallback;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.SparseArray;
import android.view.KeyEvent;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.lang.ref.WeakReference;
import java.util.List;

public final class CarInputManager extends CarManagerBase {
    public static final int CAPTURE_REQ_FLAGS_ALLOW_DELAYED_GRANT = 1;
    public static final int CAPTURE_REQ_FLAGS_TAKE_ALL_EVENTS_FOR_DISPLAY = 2;
    public static final int INPUT_CAPTURE_RESPONSE_DELAYED = 2;
    public static final int INPUT_CAPTURE_RESPONSE_FAILED = 1;
    public static final int INPUT_CAPTURE_RESPONSE_SUCCEEDED = 0;
    public static final int INPUT_TYPE_ALL_INPUTS = 1;
    public static final int INPUT_TYPE_DPAD_KEYS = 100;
    public static final int INPUT_TYPE_NAVIGATE_KEYS = 101;
    public static final int INPUT_TYPE_ROTARY_NAVIGATION = 10;
    public static final int INPUT_TYPE_ROTARY_VOLUME = 11;
    public static final int INPUT_TYPE_SYSTEM_NAVIGATE_KEYS = 102;
    public static final int TARGET_DISPLAY_TYPE_CLUSTER = 1;
    public static final int TARGET_DISPLAY_TYPE_MAIN = 0;
    private final SparseArray<CarInputCaptureCallback> mCarInputCaptureCallbacks = new SparseArray<>(1);
    private final Object mLock = new Object();
    private final ICarInput mService;
    private final ICarInputCallback mServiceCallback = new ICarInputCallbackImpl();

    @Retention(RetentionPolicy.SOURCE)
    @interface CaptureRequestFlags {
    }

    public interface CarInputCaptureCallback {
        void onCaptureStateChanged(int i, int[] iArr);

        void onKeyEvents(int i, List<KeyEvent> list);

        void onRotaryEvents(int i, List<RotaryEvent> list);
    }

    @Target({ElementType.TYPE_USE})
    @Retention(RetentionPolicy.SOURCE)
    public @interface InputCaptureResponseEnum {
    }

    @Target({ElementType.TYPE_USE})
    @Retention(RetentionPolicy.SOURCE)
    public @interface InputTypeEnum {
    }

    @Target({ElementType.TYPE_USE})
    @Retention(RetentionPolicy.SOURCE)
    public @interface TargetDisplayTypeEnum {
    }

    public CarInputManager(Car car, IBinder iBinder) {
        super(car);
        this.mService = ICarInput.Stub.asInterface(iBinder);
    }

    public int requestInputEventCapture(CarInputCaptureCallback carInputCaptureCallback, int i, int[] iArr, int i2) {
        synchronized (this.mLock) {
            this.mCarInputCaptureCallbacks.put(i, carInputCaptureCallback);
        }
        try {
            return this.mService.requestInputEventCapture(this.mServiceCallback, i, iArr, i2);
        } catch (RemoteException e) {
            return ((Integer) handleRemoteExceptionFromCarService(e, 1)).intValue();
        }
    }

    public void releaseInputEventCapture(int i) {
        CarInputCaptureCallback carInputCaptureCallback;
        synchronized (this.mLock) {
            carInputCaptureCallback = (CarInputCaptureCallback) this.mCarInputCaptureCallbacks.removeReturnOld(i);
        }
        if (carInputCaptureCallback != null) {
            try {
                this.mService.releaseInputEventCapture(this.mServiceCallback, i);
            } catch (RemoteException unused) {
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // android.car.CarManagerBase
    public void onCarDisconnected() {
        synchronized (this.mLock) {
            this.mCarInputCaptureCallbacks.clear();
        }
    }

    private CarInputCaptureCallback getCallback(int i) {
        CarInputCaptureCallback carInputCaptureCallback;
        synchronized (this.mLock) {
            carInputCaptureCallback = this.mCarInputCaptureCallbacks.get(i);
        }
        return carInputCaptureCallback;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dispatchKeyEvents(int i, List<KeyEvent> list) {
        getEventHandler().post(new Runnable(i, list) {
            /* class android.car.input.$$Lambda$CarInputManager$acEgbPxc_WimnzZZihOb8pZF0uA */
            public final /* synthetic */ int f$1;
            public final /* synthetic */ List f$2;

            {
                this.f$1 = r2;
                this.f$2 = r3;
            }

            public final void run() {
                CarInputManager.this.lambda$dispatchKeyEvents$0$CarInputManager(this.f$1, this.f$2);
            }
        });
    }

    public /* synthetic */ void lambda$dispatchKeyEvents$0$CarInputManager(int i, List list) {
        CarInputCaptureCallback callback = getCallback(i);
        if (callback != null) {
            callback.onKeyEvents(i, list);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dispatchRotaryEvents(int i, List<RotaryEvent> list) {
        getEventHandler().post(new Runnable(i, list) {
            /* class android.car.input.$$Lambda$CarInputManager$E7vSstk9ppU88BV5J50DPCtrhmw */
            public final /* synthetic */ int f$1;
            public final /* synthetic */ List f$2;

            {
                this.f$1 = r2;
                this.f$2 = r3;
            }

            public final void run() {
                CarInputManager.this.lambda$dispatchRotaryEvents$1$CarInputManager(this.f$1, this.f$2);
            }
        });
    }

    public /* synthetic */ void lambda$dispatchRotaryEvents$1$CarInputManager(int i, List list) {
        CarInputCaptureCallback callback = getCallback(i);
        if (callback != null) {
            callback.onRotaryEvents(i, list);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dispatchOnCaptureStateChanged(int i, int[] iArr) {
        getEventHandler().post(new Runnable(i, iArr) {
            /* class android.car.input.$$Lambda$CarInputManager$VIFNDzXrX1abmku3h7azjaIdrB8 */
            public final /* synthetic */ int f$1;
            public final /* synthetic */ int[] f$2;

            {
                this.f$1 = r2;
                this.f$2 = r3;
            }

            public final void run() {
                CarInputManager.this.lambda$dispatchOnCaptureStateChanged$2$CarInputManager(this.f$1, this.f$2);
            }
        });
    }

    public /* synthetic */ void lambda$dispatchOnCaptureStateChanged$2$CarInputManager(int i, int[] iArr) {
        CarInputCaptureCallback callback = getCallback(i);
        if (callback != null) {
            callback.onCaptureStateChanged(i, iArr);
        }
    }

    private static final class ICarInputCallbackImpl extends ICarInputCallback.Stub {
        private final WeakReference<CarInputManager> mManager;

        private ICarInputCallbackImpl(CarInputManager carInputManager) {
            this.mManager = new WeakReference<>(carInputManager);
        }

        @Override // android.car.input.ICarInputCallback
        public void onKeyEvents(int i, List<KeyEvent> list) {
            CarInputManager carInputManager = this.mManager.get();
            if (carInputManager != null) {
                carInputManager.dispatchKeyEvents(i, list);
            }
        }

        @Override // android.car.input.ICarInputCallback
        public void onRotaryEvents(int i, List<RotaryEvent> list) {
            CarInputManager carInputManager = this.mManager.get();
            if (carInputManager != null) {
                carInputManager.dispatchRotaryEvents(i, list);
            }
        }

        @Override // android.car.input.ICarInputCallback
        public void onCaptureStateChanged(int i, int[] iArr) {
            CarInputManager carInputManager = this.mManager.get();
            if (carInputManager != null) {
                carInputManager.dispatchOnCaptureStateChanged(i, iArr);
            }
        }
    }
}
