package android.car.watchdog;

import android.annotation.SystemApi;
import android.car.Car;
import android.car.CarManagerBase;
import android.car.watchdog.CarWatchdogManager;
import android.car.watchdog.ICarWatchdogService;
import android.car.watchdog.ICarWatchdogServiceCallback;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper;
import android.os.RemoteException;
import android.util.Log;
import com.android.internal.util.Preconditions;
import com.android.internal.util.function.pooled.PooledLambda;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.lang.ref.WeakReference;
import java.util.concurrent.Executor;

@SystemApi
public final class CarWatchdogManager extends CarManagerBase {
    private static final boolean DEBUG = false;
    private static final int INVALID_SESSION_ID = -1;
    private static final int NUMBER_OF_CONDITIONS_TO_BE_MET = 2;
    private static final String TAG = "CarWatchdogManager";
    public static final int TIMEOUT_CRITICAL = 0;
    public static final int TIMEOUT_MODERATE = 1;
    public static final int TIMEOUT_NORMAL = 2;
    private static final int WHAT_CHECK_MAIN_THREAD = 1;
    private Executor mCallbackExecutor;
    private final ICarWatchdogClientImpl mClientImpl;
    private final Object mLock = new Object();
    private final Handler mMainHandler = new Handler(Looper.getMainLooper());
    private CarWatchdogClientCallback mRegisteredClient;
    private int mRemainingConditions;
    private final ICarWatchdogService mService;
    private SessionInfo mSession = new SessionInfo(-1, -1);

    public static abstract class CarWatchdogClientCallback {
        public boolean onCheckHealthStatus(int i, int i2) {
            return false;
        }

        public void onPrepareProcessTermination() {
        }
    }

    @Target({ElementType.TYPE_USE})
    @Retention(RetentionPolicy.SOURCE)
    public @interface TimeoutLengthEnum {
    }

    @Override // android.car.CarManagerBase
    public void onCarDisconnected() {
    }

    public CarWatchdogManager(Car car, IBinder iBinder) {
        super(car);
        this.mService = ICarWatchdogService.Stub.asInterface(iBinder);
        this.mClientImpl = new ICarWatchdogClientImpl();
    }

    public void registerClient(Executor executor, CarWatchdogClientCallback carWatchdogClientCallback, int i) {
        synchronized (this.mLock) {
            CarWatchdogClientCallback carWatchdogClientCallback2 = this.mRegisteredClient;
            if (carWatchdogClientCallback2 != carWatchdogClientCallback) {
                if (carWatchdogClientCallback2 == null) {
                    this.mRegisteredClient = carWatchdogClientCallback;
                    this.mCallbackExecutor = executor;
                    try {
                        this.mService.registerClient(this.mClientImpl, i);
                    } catch (RemoteException e) {
                        synchronized (this.mLock) {
                            this.mRegisteredClient = null;
                            handleRemoteExceptionFromCarService(e);
                        }
                    }
                } else {
                    throw new IllegalStateException("Cannot register the client. Only one client can be registered.");
                }
            }
        }
    }

    public void unregisterClient(CarWatchdogClientCallback carWatchdogClientCallback) {
        synchronized (this.mLock) {
            if (this.mRegisteredClient != carWatchdogClientCallback) {
                Log.w(TAG, "Cannot unregister the client. It has not been registered.");
                return;
            }
            this.mRegisteredClient = null;
            this.mCallbackExecutor = null;
            try {
                this.mService.unregisterClient(this.mClientImpl);
            } catch (RemoteException e) {
                handleRemoteExceptionFromCarService(e);
            }
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0036, code lost:
        if (r4 == false) goto L_?;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0038, code lost:
        reportToService(r5);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:25:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:26:?, code lost:
        return;
     */
    public void tellClientAlive(CarWatchdogClientCallback carWatchdogClientCallback, int i) {
        synchronized (this.mLock) {
            if (this.mRegisteredClient == carWatchdogClientCallback) {
                Preconditions.checkArgument(i != -1 && this.mSession.currentId == i, "Cannot report client status. The given session id doesn't match the current one.");
                if (this.mSession.lastReportedId == i) {
                    Log.w(TAG, "The given session id is already reported.");
                    return;
                }
                this.mSession.lastReportedId = i;
                this.mRemainingConditions--;
                boolean checkConditionLocked = checkConditionLocked();
            } else {
                throw new IllegalStateException("Cannot report client status. The client has not been registered.");
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void checkClientStatus(int i, int i2) {
        this.mMainHandler.removeMessages(1);
        synchronized (this.mLock) {
            if (this.mRegisteredClient == null) {
                Log.w(TAG, "Cannot check client status. The client has not been registered.");
                return;
            }
            this.mSession.currentId = i;
            CarWatchdogClientCallback carWatchdogClientCallback = this.mRegisteredClient;
            Executor executor = this.mCallbackExecutor;
            this.mRemainingConditions = 2;
            this.mMainHandler.sendMessage(PooledLambda.obtainMessage($$Lambda$CarWatchdogManager$kpBI_J5B2Vj7dW8aDTd_ocm4rNw.INSTANCE, this).setWhat(1));
            executor.execute(new Runnable(carWatchdogClientCallback, i, i2) {
                /* class android.car.watchdog.$$Lambda$CarWatchdogManager$JvRXN1a4kC1SuaHkzLMG7zBJI */
                public final /* synthetic */ CarWatchdogManager.CarWatchdogClientCallback f$1;
                public final /* synthetic */ int f$2;
                public final /* synthetic */ int f$3;

                {
                    this.f$1 = r2;
                    this.f$2 = r3;
                    this.f$3 = r4;
                }

                public final void run() {
                    CarWatchdogManager.this.lambda$checkClientStatus$0$CarWatchdogManager(this.f$1, this.f$2, this.f$3);
                }
            });
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0020, code lost:
        if (r3 == false) goto L_?;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:12:0x0022, code lost:
        reportToService(r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:?, code lost:
        return;
     */
    public /* synthetic */ void lambda$checkClientStatus$0$CarWatchdogManager(CarWatchdogClientCallback carWatchdogClientCallback, int i, int i2) {
        if (carWatchdogClientCallback.onCheckHealthStatus(i, i2)) {
            synchronized (this.mLock) {
                if (this.mSession.lastReportedId != i) {
                    this.mSession.lastReportedId = i;
                    this.mRemainingConditions--;
                    boolean checkConditionLocked = checkConditionLocked();
                }
            }
        }
    }

    /* access modifiers changed from: private */
    public void checkMainThread() {
        int i;
        boolean checkConditionLocked;
        synchronized (this.mLock) {
            this.mRemainingConditions--;
            i = this.mSession.currentId;
            checkConditionLocked = checkConditionLocked();
        }
        if (checkConditionLocked) {
            reportToService(i);
        }
    }

    private boolean checkConditionLocked() {
        if (this.mRemainingConditions < 0) {
            Log.wtf(TAG, "Remaining condition is less than zero: should not happen");
        }
        return this.mRemainingConditions == 0;
    }

    private void reportToService(int i) {
        try {
            this.mService.tellClientAlive(this.mClientImpl, i);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notifyProcessTermination() {
        synchronized (this.mLock) {
            CarWatchdogClientCallback carWatchdogClientCallback = this.mRegisteredClient;
            if (carWatchdogClientCallback == null) {
                Log.w(TAG, "Cannot notify the client. The client has not been registered.");
                return;
            }
            this.mCallbackExecutor.execute(new Runnable() {
                /* class android.car.watchdog.$$Lambda$CarWatchdogManager$R2mRgyzX9muX8i1IE14ge6GlEY */

                public final void run() {
                    CarWatchdogManager.CarWatchdogClientCallback.this.onPrepareProcessTermination();
                }
            });
        }
    }

    /* access modifiers changed from: private */
    public static final class ICarWatchdogClientImpl extends ICarWatchdogServiceCallback.Stub {
        private final WeakReference<CarWatchdogManager> mManager;

        private ICarWatchdogClientImpl(CarWatchdogManager carWatchdogManager) {
            this.mManager = new WeakReference<>(carWatchdogManager);
        }

        @Override // android.car.watchdog.ICarWatchdogServiceCallback
        public void onCheckHealthStatus(int i, int i2) {
            CarWatchdogManager carWatchdogManager = this.mManager.get();
            if (carWatchdogManager != null) {
                carWatchdogManager.checkClientStatus(i, i2);
            }
        }

        @Override // android.car.watchdog.ICarWatchdogServiceCallback
        public void onPrepareProcessTermination() {
            CarWatchdogManager carWatchdogManager = this.mManager.get();
            if (carWatchdogManager != null) {
                carWatchdogManager.notifyProcessTermination();
            }
        }
    }

    /* access modifiers changed from: private */
    public final class SessionInfo {
        public int currentId;
        public int lastReportedId;

        SessionInfo(int i, int i2) {
            this.currentId = i;
            this.lastReportedId = i2;
        }
    }
}
